@@ -147,7 +147,7 @@ def AddMutationArgs(parser, required=True):
                   'enable-autoupgrade':
                       arg_parsers.ArgBoolean(),
               },
-              required_keys=['type']),
+              required_keys=['type', 'enable-autoupgrade']),
       ),
       help="""\
       A non-empty list of agent rules to be enforced by the policy.
@@ -170,6 +170,12 @@ def AddMutationArgs(parser, required=True):
       https://cloud.google.com/stackdriver/docs/solutions/ops-agent#which_agent
       for which agent to use.
 
+      *enable-autoupgrade*::: Whether to enable autoupgrade of the agent.
+
+      *Required*. Allowed values: ``true'' or ``false''. This has to be
+      ``false'' if the agent version is set to a specific patch version in the
+      format of ``version=MAJOR_VERSION.MINOR_VERSION.PATCH_VERSION''.
+
       *version*::: Version of the agent to install.
 
       Optional. Default to ``version=current-major''. The allowed values and
@@ -238,7 +244,7 @@ def AddMutationArgs(parser, required=True):
       can only ensure that the agent is re-installed. It is not able to restore
       the expected exact version of the agent.
 
-      ```version=5.5.2-BUILD_NUMBER```::::
+      *version=5.5.2-BUILD_NUMBER*::::
 
       Allowed for the metrics agent (``type=metrics'') only.
 
@@ -257,7 +263,8 @@ def AddMutationArgs(parser, required=True):
       can only ensure that the agent is re-installed. It is not able to restore
       the expected exact version of the agent.
 
-      *package-state*::: Desired package state of the agent.
+      *package-state*:::
+      Desired package state of the agent.
 
       Optional. Default to ``package-state=installed''. The allowed values are
       as follows.
@@ -271,13 +278,6 @@ def AddMutationArgs(parser, required=True):
 
       With this setting, the policy will ensure the agent package is removed
       from the instances, which stops the service from running.
-
-      *enable-autoupgrade*::: Whether to enable autoupgrade of the agent.
-
-      Optional. Default to ``enable-autoupgrade=true''. Allowed values: ``true''
-      or ``false''. This has to be ``false'' if the agent version is set to a
-      specific patch version in the format of
-      ``version=MAJOR_VERSION.MINOR_VERSION.PATCH_VERSION''.
       """)
   parser.add_argument(
       '--os-types',
@@ -303,7 +303,7 @@ def AddMutationArgs(parser, required=True):
       A non-empty list of OS types to filter instances that the policy applies
       to.
 
-      For Alpha, exactly one OS type needs to be specified. The support for
+      For Alpha and Beta, exactly one OS type needs to be specified. The support for
       multiple OS types will be added later for more flexibility. Each OS type
       contains the following fields.
 
@@ -315,7 +315,7 @@ def AddMutationArgs(parser, required=True):
 
       To inspect the exact OS short name of an instance, run:
 
-        $ gcloud beta compute instances os-inventory describe INSTANCE_NAME
+        $ gcloud beta compute instances os-inventory describe INSTANCE_NAME | grep "^ShortName: "
 
       *version*::: Version of the OS.
 
@@ -324,7 +324,7 @@ def AddMutationArgs(parser, required=True):
 
       To inspect the exact OS version of an instance, run:
 
-        $ gcloud beta compute instances os-inventory describe INSTANCE_NAME
+        $ gcloud beta compute instances os-inventory describe INSTANCE_NAME | grep "^Version: "
 
       Sample values:
 
@@ -343,6 +343,8 @@ def AddMutationArgs(parser, required=True):
         ubuntu             18.04
         ubuntu             19.10
         ubuntu             20.04
+        windows            10.*
+        windows            6.*
 
       ```*``` can be used to match a prefix of the version:
       ```<VERSION_PREFIX>*``` matches any version that starts with
@@ -365,8 +367,11 @@ def _AddGroupLabelsArgument(parser):
 
       Optional. The ``--group-labels'' flag needs to be quoted. Each label map
       item in the list are separated by ```;```. To manage instance labels,
-      refer to the ```gcloud beta compute instances add-labels``` and the
-      ```gcloud beta compute instances remove-labels``` commands.
+      refer to:
+
+        $ gcloud beta compute instances add-labels
+
+        $ gcloud beta compute instances remove-labels
 
       Each label map item in the ``--group-labels'' list is a map in the format
       of ``LABEL_NAME=LABEL_VALUE,LABEL_NAME=LABEL_VALUE,...''. An instance has
