@@ -19,6 +19,7 @@ from __future__ import division
 from __future__ import unicode_literals
 
 import abc
+import enum
 import os.path
 import string
 import uuid
@@ -41,7 +42,30 @@ import six
 
 _WORKFLOWS_URL = ('https://github.com/GoogleCloudPlatform/compute-image-tools/'
                   'tree/master/daisy_workflows/image_import')
-_OUTPUT_FILTER = ['[Daisy', '[import-', 'starting build', '  import', 'ERROR']
+_OUTPUT_FILTER = [
+    '[Daisy', '[import-', '[onestep-', 'starting build', '  import', 'ERROR'
+]
+
+
+class CloudProvider(enum.Enum):
+  UNKNOWN = 0
+  AWS = 1
+
+
+def _HasAwsArgs(args):
+  return (args.aws_access_key_id or args.aws_secret_access_key or
+          args.aws_session_token or args.aws_region or args.aws_ami_id or
+          args.aws_ami_export_location or args.aws_source_ami_file_path)
+
+
+def _HasExternalCloudProvider(args):
+  return _GetExternalCloudProvider(args) != CloudProvider.UNKNOWN
+
+
+def _GetExternalCloudProvider(args):
+  if _HasAwsArgs(args):
+    return CloudProvider.AWS
+  return CloudProvider.UNKNOWN
 
 
 def _AppendTranslateWorkflowArg(args, import_args):
@@ -51,6 +75,27 @@ def _AppendTranslateWorkflowArg(args, import_args):
                         args.custom_workflow)
 
 
+def _AppendAwsArgs(args, import_args):
+  """Appends args related to AWS image import."""
+
+  daisy_utils.AppendArg(import_args, 'aws_access_key_id',
+                        args.aws_access_key_id)
+  daisy_utils.AppendArg(import_args, 'aws_secret_access_key',
+                        args.aws_secret_access_key)
+  daisy_utils.AppendArg(import_args, 'aws_session_token',
+                        args.aws_session_token)
+  daisy_utils.AppendArg(import_args, 'aws_region', args.aws_region)
+
+  if args.aws_ami_id:
+    daisy_utils.AppendArg(import_args, 'aws_ami_id', args.aws_ami_id)
+  if args.aws_ami_export_location:
+    daisy_utils.AppendArg(import_args, 'aws_ami_export_location',
+                          args.aws_ami_export_location)
+  if args.aws_source_ami_file_path:
+    daisy_utils.AppendArg(import_args, 'aws_source_ami_file_path',
+                          args.aws_source_ami_file_path)
+
+
 def _CheckImageName(image_name):
   """Checks for a valid GCE image name."""
   name_message = ('Name must start with a lowercase letter followed by up to '
@@ -96,7 +141,6 @@ class Import(base.CreateCommand):
   """Import an image into Compute Engine."""
 
   _OS_CHOICES = os_choices.OS_CHOICES_IMAGE_IMPORT_GA
-  _OS_FLAG_REQUIRED = True
 
   def __init__(self, *args, **kwargs):
     self.storage_client = storage_api.StorageClient()
@@ -111,17 +155,36 @@ class Import(base.CreateCommand):
         parser, 'image', 'import',
         explanation='The zone in which to do the work of importing the image.')
 
-    source = parser.add_mutually_exclusive_group(required=True)
-    source.add_argument(
-        '--source-file',
-        help=("""A local file, or the Cloud Storage URI of the virtual
+    if cls.ReleaseTrack() == base.ReleaseTrack.GA:
+      source = parser.add_mutually_exclusive_group(required=True)
+      source.add_argument(
+          '--source-file',
+          help=("""A local file, or the Cloud Storage URI of the virtual
               disk file to import. For example: ``gs://my-bucket/my-image.vmdk''
               or ``./my-local-image.vmdk''"""),
-    )
-    flags.SOURCE_IMAGE_ARG.AddArgument(source, operation_type='import')
+      )
+      flags.SOURCE_IMAGE_ARG.AddArgument(source, operation_type='import')
+    else:
+      source = parser.add_mutually_exclusive_group(required=True)
 
-    workflow = parser.add_mutually_exclusive_group(
-        required=cls._OS_FLAG_REQUIRED)
+      import_from_local_or_gcs = source.add_mutually_exclusive_group(
+          help='Image import from local file, Cloud Storage or Compute Engine image.'
+      )
+      import_from_local_or_gcs.add_argument(
+          '--source-file',
+          help=("""A local file, or the Cloud Storage URI of the virtual
+                disk file to import. For example: ``gs://my-bucket/my-image.vmdk''
+                or ``./my-local-image.vmdk''"""),
+      )
+      flags.SOURCE_IMAGE_ARG.AddArgument(
+          import_from_local_or_gcs, operation_type='import')
+
+      import_from_aws = source.add_group(
+          help='Image import from AWS.'
+      )
+      daisy_utils.AddAWSImageImportSourceArgs(import_from_aws)
+
+    workflow = parser.add_mutually_exclusive_group()
     workflow.add_argument(
         '--os',
         choices=sorted(cls._OS_CHOICES),
@@ -201,6 +264,10 @@ class Import(base.CreateCommand):
         'https://cloud.google.com/compute/docs/import/importing-virtual-disks#no-external-ip'
     )
 
+    daisy_utils.AddComputeServiceAccountArg(
+        parser, 'image import',
+        daisy_utils.IMPORT_ROLES_FOR_COMPUTE_SERVICE_ACCOUNT)
+
   def Run(self, args):
     compute_holder = base_classes.ComputeApiHolder(self.ReleaseTrack())
 
@@ -229,6 +296,10 @@ class Import(base.CreateCommand):
         if self.ReleaseTrack() else None)
 
   def _CreateImportStager(self, args):
+    if self.ReleaseTrack(
+    ) != base.ReleaseTrack.GA and _HasExternalCloudProvider(args):
+      return ImportFromExternalCloudProviderStager(self.storage_client, args)
+
     if args.source_image:
       return ImportFromImageStager(
           self.storage_client, args)
@@ -295,7 +366,9 @@ class BaseImportStager(object):
     if 'no_address' in self.args:
       daisy_utils.AppendBoolArg(import_args, 'no_external_ip',
                                 self.args.no_address)
-
+    if 'compute_service_account' in self.args:
+      daisy_utils.AppendArg(import_args, 'compute_service_account',
+                            self.args.compute_service_account)
     return import_args
 
   def GetAndCreateDaisyBucket(self):
@@ -309,6 +382,20 @@ class BaseImportStager(object):
     return None
 
 
+class ImportFromExternalCloudProviderStager(BaseImportStager):
+  """Image import stager from an external cloud provider."""
+
+  def Stage(self):
+    import_args = []
+
+    _AppendAwsArgs(self.args, import_args)
+    _AppendTranslateWorkflowArg(self.args, import_args)
+
+    import_args.extend(
+        super(ImportFromExternalCloudProviderStager, self).Stage())
+    return import_args
+
+
 class ImportFromImageStager(BaseImportStager):
   """Image import stager from an existing image."""
 
@@ -431,7 +518,6 @@ class ImportBeta(Import):
   """Import an image into Compute Engine for beta releases."""
 
   _OS_CHOICES = os_choices.OS_CHOICES_IMAGE_IMPORT_BETA
-  _OS_FLAG_REQUIRED = False
 
   @classmethod
   def Args(cls, parser):
@@ -439,6 +525,15 @@ class ImportBeta(Import):
     daisy_utils.AddExtraCommonDaisyArgs(parser)
 
   def _RunImageImport(self, args, import_args, tags, output_filter):
+    if _HasExternalCloudProvider(args):
+      return daisy_utils.RunOnestepImageImport(
+          args,
+          import_args,
+          tags,
+          _OUTPUT_FILTER,
+          release_track=self.ReleaseTrack().id.lower()
+          if self.ReleaseTrack() else None,
+          docker_image_tag=args.docker_image_tag)
     return daisy_utils.RunImageImport(
         args,
         import_args,
@@ -457,41 +552,6 @@ class ImportAlpha(ImportBeta):
 
 
 Import.detailed_help = {
-    'brief': 'Import an image into Compute Engine',
-    'DESCRIPTION': """
-        *{command}* imports Virtual Disk images, such as VMWare VMDK files
-        and VHD files, into Compute Engine.
-
-        Importing images involves three steps:
-        *  Upload the virtual disk file to Cloud Storage.
-        *  Import the image to Compute Engine.
-        *  Translate the image to make a bootable image.
-        This command performs all three of these steps as required,
-        depending on the input arguments specified.
-
-        This command uses the `--os` flag to choose the appropriate translation.
-        You can omit the translation step using the `--data-disk` flag.
-
-        If you exported your disk from Compute Engine then you don't
-        need to re-import it. Instead, use `{parent_command} create`
-        to create more images from the disk.
-
-        Files stored on Cloud Storage and images in Compute Engine incur
-        charges. See [](https://cloud.google.com/compute/docs/images/importing-virtual-disks#resource_cleanup).
-        """,
-
-    'EXAMPLES': """
-        To import a centos-7 VMDK file, run:
-
-          $ {command} myimage-name --os=centos-7 --source-file=mysourcefile
-
-        To import a data disk without operating system, run:
-
-          $ {command} myimage-name --data-disk --source-file=mysourcefile
-        """,
-}
-
-ImportBeta.detailed_help = {
     'brief': 'Import an image into Compute Engine',
     'DESCRIPTION': """
         *{command}* imports Virtual Disk images, such as VMWare VMDK files
