@@ -76,8 +76,8 @@ DETAILED_HELP = {
 
           $ {command} instance-1 --source-snapshot=https://compute.googleapis.com/compute/v1/projects/myproject/global/snapshots/instance-snapshot --zone=central2-a --disk=name=disk1,scope=regional
 
-        To create an instance called instance-1 as a shielded vm with
-        secure boot, virtual trusted platform module (vTPM) enabled and
+        To create an instance called instance-1 as a Shielded VM instance with
+        Secure Boot, virtual trusted platform module (vTPM) enabled and
         integrity monitoring, run:
 
           $ {command} instance-1 --zone=central2-a --shielded-secure-boot --shielded-vtpm --shielded-integrity-monitoring
@@ -149,6 +149,7 @@ def _CommonArgs(parser,
   instances_flags.AddShieldedInstanceConfigArgs(parser)
   instances_flags.AddDisplayDeviceArg(parser)
   instances_flags.AddMinNodeCpuArg(parser)
+  instances_flags.AddNestedVirtualizationArgs(parser)
 
   instances_flags.AddReservationAffinityGroup(
       parser,
@@ -202,7 +203,6 @@ class Create(base.CreateCommand):
   _support_create_disk_snapshots = True
   _support_boot_snapshot_uri = True
   _enable_pd_interface = False
-  _support_enable_nested_virtualization = False
   _support_threads_per_core = False
   _support_replica_zones = False
   _support_multi_writer = False
@@ -210,6 +210,7 @@ class Create(base.CreateCommand):
   _support_stack_type = False
   _support_ipv6_network_tier = False
   _support_ipv6_public_ptr_domain = False
+  _support_network_performance_configs = False
 
   @classmethod
   def Args(cls, parser):
@@ -379,14 +380,15 @@ class Create(base.CreateCommand):
                 compute_client.messages).GetEnumForChoice(
                     args.private_ipv6_google_access_type))
 
-      if ((self._support_enable_nested_virtualization and
-           args.enable_nested_virtualization is not None) or
-          (self._support_threads_per_core and
-           args.threads_per_core is not None)):
+      has_threads_per_core = (
+          self._support_threads_per_core and args.threads_per_core is not None)
+      if (args.enable_nested_virtualization is not None or
+          has_threads_per_core):
+        threads_per_core = args.threads_per_core if has_threads_per_core else None
         instance.advancedMachineFeatures = (
             instance_utils.CreateAdvancedMachineFeaturesMessage(
                 compute_client.messages, args.enable_nested_virtualization,
-                args.threads_per_core))
+                threads_per_core))
 
       resource_policies = getattr(args, 'resource_policies', None)
       if resource_policies:
@@ -416,6 +418,11 @@ class Create(base.CreateCommand):
             args.post_key_revocation_action_type, compute_client.messages
             .Instance.PostKeyRevocationActionTypeValueValuesEnum)
 
+      if self._support_network_performance_configs and \
+          args.IsSpecified('network_performance_configs'):
+        instance.networkPerformanceConfig = \
+            instance_utils.GetNetworkPerformanceConfig(args, compute_client)
+
       request = compute_client.messages.ComputeInstancesInsertRequest(
           instance=instance,
           project=instance_ref.project,
@@ -465,6 +472,9 @@ class Create(base.CreateCommand):
     instances_flags.ValidateNetworkTierArgs(args)
     instances_flags.ValidateReservationAffinityGroup(args)
 
+    if self._support_network_performance_configs:
+      instances_flags.ValidateNetworkPerformanceConfigsArgs(args)
+
     holder = base_classes.ComputeApiHolder(self.ReleaseTrack())
     compute_client = holder.client
     resource_parser = holder.resources
@@ -608,7 +618,6 @@ class CreateAlpha(CreateBeta):
   _support_create_disk_snapshots = True
   _support_boot_snapshot_uri = True
   _enable_pd_interface = True
-  _support_enable_nested_virtualization = True
   _support_threads_per_core = True
   _support_replica_zones = True
   _support_multi_writer = True
@@ -616,6 +625,7 @@ class CreateAlpha(CreateBeta):
   _support_stack_type = True
   _support_ipv6_network_tier = True
   _support_ipv6_public_ptr_domain = True
+  _support_network_performance_configs = True
 
   @classmethod
   def Args(cls, parser):
@@ -649,10 +659,10 @@ class CreateAlpha(CreateBeta):
     instances_flags.AddPrivateIpv6GoogleAccessArg(
         parser, utils.COMPUTE_ALPHA_API_VERSION)
     instances_flags.AddStableFleetArgs(parser)
-    instances_flags.AddNestedVirtualizationArgs(parser)
     instances_flags.AddThreadsPerCoreArgs(parser)
     instances_flags.AddStackTypeArgs(parser)
     instances_flags.AddIpv6NetworkTierArgs(parser)
+    instances_flags.AddNetworkPerformanceConfigsArgs(parser)
 
 
 Create.detailed_help = DETAILED_HELP
