@@ -72,6 +72,7 @@ struct ast_channel_snapshot {
 	struct ast_flags softhangup_flags;      /*!< softhangup channel flags */
 	struct varshead *manager_vars;          /*!< Variables to be appended to manager events */
 	int tech_properties;                    /*!< Properties of the channel's technology */
+	struct varshead *ari_vars;              /*!< Variables to be appended to ARI events */
 };
 
 /*!
@@ -98,7 +99,7 @@ struct stasis_cp_all *ast_channel_cache_all(void);
 /*!
  * \since 12
  * \brief A topic which publishes the events for all channels.
- * \retval Topic for all channel events.
+ * \return Topic for all channel events.
  */
 struct stasis_topic *ast_channel_topic_all(void);
 
@@ -115,7 +116,7 @@ struct stasis_topic *ast_channel_topic_all_cached(void);
  * \since 12
  * \brief Primary channel cache, indexed by Uniqueid.
  *
- * \retval Cache of \ref ast_channel_snapshot.
+ * \return Cache of \ref ast_channel_snapshot.
  */
 struct stasis_cache *ast_channel_cache(void);
 
@@ -144,7 +145,7 @@ struct stasis_message_type *ast_channel_snapshot_type(void);
  *
  * \param chan The channel from which to generate a snapshot
  *
- * \retval pointer on success (must be unreffed)
+ * \return pointer on success (must be unreffed)
  * \retval NULL on error
  */
 struct ast_channel_snapshot *ast_channel_snapshot_create(
@@ -155,9 +156,9 @@ struct ast_channel_snapshot *ast_channel_snapshot_create(
  * \brief Obtain the latest \ref ast_channel_snapshot from the \ref stasis cache. This is
  * an ao2 object, so use \ref ao2_cleanup() to deallocate.
  *
- * \param unique_id The channel's unique ID
+ * \param uniqueid The channel's unique ID
  *
- * \retval A \ref ast_channel_snapshot on success
+ * \return A \ref ast_channel_snapshot on success
  * \retval NULL on error
  */
 struct ast_channel_snapshot *ast_channel_snapshot_get_latest(const char *uniqueid);
@@ -169,7 +170,7 @@ struct ast_channel_snapshot *ast_channel_snapshot_get_latest(const char *uniquei
  *
  * \param name The channel's name
  *
- * \retval A \ref ast_channel_snapshot on success
+ * \return A \ref ast_channel_snapshot on success
  * \retval NULL on error
  */
 struct ast_channel_snapshot *ast_channel_snapshot_get_latest_by_name(const char *name);
@@ -189,7 +190,7 @@ struct ast_channel_snapshot *ast_channel_snapshot_get_latest_by_name(const char
  *             \c NULL, ast_json_null() is put into the object.
  *
  * \return \ref ast_channel_blob message.
- * \return \c NULL on error
+ * \retval NULL on error
  */
 struct stasis_message *ast_channel_blob_create(struct ast_channel *chan,
 	struct stasis_message_type *type, struct ast_json *blob);
@@ -205,7 +206,7 @@ struct stasis_message *ast_channel_blob_create(struct ast_channel *chan,
  *             \c NULL, ast_json_null() is put into the object.
  *
  * \return \ref ast_channel_blob message.
- * \return \c NULL on error
+ * \retval NULL on error
  */
 struct stasis_message *ast_channel_blob_create_from_cache(
 	const char *uniqueid, struct stasis_message_type *type,
@@ -221,7 +222,7 @@ struct stasis_message *ast_channel_blob_create_from_cache(
  * \param blob The JSON blob that defines the data of this \ref ast_multi_channel_blob
  *
  * \return \ref ast_multi_channel_blob object
- * \return \c NULL on error
+ * \retval NULL on error
 */
 struct ast_multi_channel_blob *ast_multi_channel_blob_create(struct ast_json *blob);
 
@@ -238,7 +239,7 @@ struct ast_multi_channel_blob *ast_multi_channel_blob_create(struct ast_json *bl
  * to retrieve
  * \param role The role associated with the channel snapshot
  *
- * \retval \ref ast_channel_snapshot matching the role on success
+ * \return \ref ast_channel_snapshot matching the role on success
  * \retval NULL on error or not found for the role specified
  */
 struct ast_channel_snapshot *ast_multi_channel_blob_get_channel(
@@ -259,7 +260,7 @@ struct ast_channel_snapshot *ast_multi_channel_blob_get_channel(
  * retrieve
  * \param role The role associated with the channel snapshots
  *
- * \retval A container containing all \ref ast_channel_snapshot objects matching
+ * \return A container containing all \ref ast_channel_snapshot objects matching
  * the role on success.
  * \retval NULL on error or not found for the role specified
  */
@@ -273,7 +274,7 @@ struct ao2_container *ast_multi_channel_blob_get_channels(
  *
  * \param obj Channel blob object.
  * \return Type field value from the blob.
- * \return \c NULL on error.
+ * \retval NULL on error.
  */
 struct ast_json *ast_multi_channel_blob_get_json(struct ast_multi_channel_blob *obj);
 
@@ -301,8 +302,6 @@ void ast_multi_channel_blob_add_channel(struct ast_multi_channel_blob *obj,
  * \param chan Channel publishing the blob.
  * \param type Type of stasis message.
  * \param blob The blob being published. (NULL if no blob)
- *
- * \return Nothing
  */
 void ast_channel_publish_blob(struct ast_channel *chan, struct stasis_message_type *type,
 	struct ast_json *blob);
@@ -318,8 +317,6 @@ void ast_channel_publish_blob(struct ast_channel *chan, struct stasis_message_ty
  * \note As this only accesses the uniqueid and topic of the channel - neither of
  * which should ever be changed on a channel anyhow - a channel does not have to
  * be locked when calling this function.
- *
- * \return Nothing
  */
 void ast_channel_publish_cached_blob(struct ast_channel *chan, struct stasis_message_type *type,
 	struct ast_json *blob);
@@ -356,7 +353,7 @@ void ast_channel_publish_snapshot(struct ast_channel *chan);
 
 /*!
  * \since 12
- * \brief Publish a \ref ast_channel_varset for a channel.
+ * \brief Publish a \ref ast_channel_publish_varset for a channel.
  *
  * \pre chan is locked
  *
@@ -371,7 +368,7 @@ void ast_channel_publish_varset(struct ast_channel *chan,
  * \since 12
  * \brief Message type for when a channel dials another channel
  *
- * \retval A stasis message type
+ * \return A stasis message type
  */
 struct stasis_message_type *ast_channel_dial_type(void);
 
@@ -379,7 +376,7 @@ struct stasis_message_type *ast_channel_dial_type(void);
  * \since 12
  * \brief Message type for when a variable is set on a channel.
  *
- * \retval A stasis message type
+ * \return A stasis message type
  */
 struct stasis_message_type *ast_channel_varset_type(void);
 
@@ -387,15 +384,23 @@ struct stasis_message_type *ast_channel_varset_type(void);
  * \since 12
  * \brief Message type for when a hangup is requested on a channel.
  *
- * \retval A stasis message type
+ * \return A stasis message type
  */
 struct stasis_message_type *ast_channel_hangup_request_type(void);
 
+/*!
+ * \since 16
+ * \brief Message type for when a channel is being masqueraded
+ *
+ * \return A stasis message type
+ */
+struct stasis_message_type *ast_channel_masquerade_type(void);
+
 /*!
  * \since 12
  * \brief Message type for when DTMF begins on a channel.
  *
- * \retval A stasis message type
+ * \return A stasis message type
  */
 struct stasis_message_type *ast_channel_dtmf_begin_type(void);
 
@@ -403,15 +408,22 @@ struct stasis_message_type *ast_channel_dtmf_begin_type(void);
  * \since 12
  * \brief Message type for when DTMF ends on a channel.
  *
- * \retval A stasis message type
+ * \return A stasis message type
  */
 struct stasis_message_type *ast_channel_dtmf_end_type(void);
 
+/*!
+ * \brief Message type for when a hook flash occurs on a channel.
+ *
+ * \return A stasis message type
+ */
+struct stasis_message_type *ast_channel_flash_type(void);
+
 /*!
  * \since 12
  * \brief Message type for when a channel is placed on hold.
  *
- * \retval A stasis message type
+ * \return A stasis message type
  */
 struct stasis_message_type *ast_channel_hold_type(void);
 
@@ -419,7 +431,7 @@ struct stasis_message_type *ast_channel_hold_type(void);
  * \since 12
  * \brief Message type for when a channel is removed from hold.
  *
- * \retval A stasis message type
+ * \return A stasis message type
  */
 struct stasis_message_type *ast_channel_unhold_type(void);
 
@@ -427,7 +439,7 @@ struct stasis_message_type *ast_channel_unhold_type(void);
  * \since 12
  * \brief Message type for when a channel starts spying on another channel
  *
- * \retval A stasis message type
+ * \return A stasis message type
  */
 struct stasis_message_type *ast_channel_chanspy_start_type(void);
 
@@ -435,7 +447,7 @@ struct stasis_message_type *ast_channel_chanspy_start_type(void);
  * \since 12
  * \brief Message type for when a channel stops spying on another channel
  *
- * \retval A stasis message type
+ * \return A stasis message type
  */
 struct stasis_message_type *ast_channel_chanspy_stop_type(void);
 
@@ -443,7 +455,7 @@ struct stasis_message_type *ast_channel_chanspy_stop_type(void);
  * \since 12
  * \brief Message type for a fax operation
  *
- * \retval A stasis message type
+ * \return A stasis message type
  */
 struct stasis_message_type *ast_channel_fax_type(void);
 
@@ -451,7 +463,7 @@ struct stasis_message_type *ast_channel_fax_type(void);
  * \since 12
  * \brief Message type for hangup handler related actions
  *
- * \retval A stasis message type
+ * \return A stasis message type
  */
 struct stasis_message_type *ast_channel_hangup_handler_type(void);
 
@@ -459,7 +471,7 @@ struct stasis_message_type *ast_channel_hangup_handler_type(void);
  * \since 12
  * \brief Message type for starting monitor on a channel
  *
- * \retval A stasis message type
+ * \return A stasis message type
  */
 struct stasis_message_type *ast_channel_monitor_start_type(void);
 
@@ -467,15 +479,39 @@ struct stasis_message_type *ast_channel_monitor_start_type(void);
  * \since 12
  * \brief Message type for stopping monitor on a channel
  *
- * \retval A stasis message type
+ * \return A stasis message type
  */
 struct stasis_message_type *ast_channel_monitor_stop_type(void);
 
 /*!
- * \since 12.0.0
+ * \since 18
+ * \brief Message type for starting mixmonitor on a channel
+ *
+ * \return A stasis message type
+ */
+struct stasis_message_type *ast_channel_mixmonitor_start_type(void);
+
+/*!
+ * \since 18
+ * \brief Message type for stopping mixmonitor on a channel
+ *
+ * \return A stasis message type
+ */
+struct stasis_message_type *ast_channel_mixmonitor_stop_type(void);
+
+/*!
+ * \since 18
+ * \brief Message type for muting or unmuting mixmonitor on a channel
+ *
+ * \return A stasis message type
+ */
+struct stasis_message_type *ast_channel_mixmonitor_mute_type(void);
+
+/*!
+ * \since 18.0.0
  * \brief Message type for agent login on a channel
  *
- * \retval A stasis message type
+ * \return A stasis message type
  */
 struct stasis_message_type *ast_channel_agent_login_type(void);
 
@@ -483,7 +519,7 @@ struct stasis_message_type *ast_channel_agent_login_type(void);
  * \since 12.0.0
  * \brief Message type for agent logoff on a channel
  *
- * \retval A stasis message type
+ * \return A stasis message type
  */
 struct stasis_message_type *ast_channel_agent_logoff_type(void);
 
@@ -491,7 +527,7 @@ struct stasis_message_type *ast_channel_agent_logoff_type(void);
  * \since 12
  * \brief Message type for starting music on hold on a channel
  *
- * \retval A stasis message type
+ * \return A stasis message type
  */
 struct stasis_message_type *ast_channel_moh_start_type(void);
 
@@ -499,7 +535,7 @@ struct stasis_message_type *ast_channel_moh_start_type(void);
  * \since 12
  * \brief Message type for stopping music on hold on a channel
  *
- * \retval A stasis message type
+ * \return A stasis message type
  */
 struct stasis_message_type *ast_channel_moh_stop_type(void);
 
@@ -507,7 +543,7 @@ struct stasis_message_type *ast_channel_moh_stop_type(void);
  * \since 12.4.0
  * \brief Message type for a channel starting talking
  *
- * \retval A stasis message type
+ * \return A stasis message type
  */
 struct stasis_message_type *ast_channel_talking_start(void);
 
@@ -515,7 +551,7 @@ struct stasis_message_type *ast_channel_talking_start(void);
  * \since 12.4.0
  * \brief Message type for a channel stopping talking
  *
- * \retval A stasis message type
+ * \return A stasis message type
  */
 struct stasis_message_type *ast_channel_talking_stop(void);
 
@@ -576,7 +612,7 @@ void ast_publish_channel_state(struct ast_channel *chan);
  * \param sanitize The message sanitizer to use on the snapshot
  *
  * \return JSON object representing channel snapshot.
- * \return \c NULL on error
+ * \retval NULL on error
  */
 struct ast_json *ast_channel_snapshot_to_json(const struct ast_channel_snapshot *snapshot,
 	const struct stasis_message_sanitizer *sanitize);
@@ -588,8 +624,8 @@ struct ast_json *ast_channel_snapshot_to_json(const struct ast_channel_snapshot
  * \param old_snapshot Old snapshot
  * \param new_snapshot New snapshot
  *
- * \return True (non-zero) if context, exten or priority are identical.
- * \return False (zero) if context, exten and priority changed.
+ * \retval True (non-zero) if context, exten or priority are identical.
+ * \retval False (zero) if context, exten and priority changed.
  */
 int ast_channel_snapshot_cep_equal(
 	const struct ast_channel_snapshot *old_snapshot,
@@ -602,8 +638,8 @@ int ast_channel_snapshot_cep_equal(
  * \param old_snapshot Old snapshot
  * \param new_snapshot New snapshot
  *
- * \return True (non-zero) if callerid are identical.
- * \return False (zero) if callerid changed.
+ * \retval True (non-zero) if callerid are identical.
+ * \retval False (zero) if callerid changed.
  */
 int ast_channel_snapshot_caller_id_equal(
 	const struct ast_channel_snapshot *old_snapshot,
@@ -616,8 +652,8 @@ int ast_channel_snapshot_caller_id_equal(
  * \param old_snapshot Old snapshot
  * \param new_snapshot New snapshot
  *
- * \return True (non-zero) if callerid are identical.
- * \return False (zero) if callerid changed.
+ * \retval True (non-zero) if callerid are identical.
+ * \retval False (zero) if callerid changed.
  */
 int ast_channel_snapshot_connected_line_equal(
 	const struct ast_channel_snapshot *old_snapshot,
@@ -625,8 +661,8 @@ int ast_channel_snapshot_connected_line_equal(
 
 /*!
  * \brief Initialize the stasis channel topic and message types
- * \return 0 on success
- * \return Non-zero on error
+ * \retval 0 on success
+ * \retval Non-zero on error
  */
 int ast_stasis_channels_init(void);
 
