@@ -34,7 +34,7 @@ extern "C" {
   /* The #define below is used for apps that dynamically link with nDPI to make
      sure that datastructures and in sync across versions
   */
-#define NDPI_API_VERSION                      7410
+#define NDPI_API_VERSION                      7194
 
 #define SIZEOF_ID_STRUCT                      ( sizeof(struct ndpi_id_struct)   )
 #define SIZEOF_FLOW_STRUCT                    ( sizeof(struct ndpi_flow_struct) )
@@ -47,6 +47,11 @@ extern "C" {
 #define SAVE_DETECTION_BITMASK_AS_UNKNOWN     1
 #define NO_SAVE_DETECTION_BITMASK_AS_UNKNOWN  0
 
+  /*
+    In case a custom DGA function is used, the fucntion
+    below must be overwritten,
+  */
+  extern ndpi_custom_dga_predict_fctn ndpi_dga_function;
 
   /**
    * Check if a string is encoded with punycode
@@ -180,7 +185,7 @@ extern "C" {
    * Returns a new initialized detection module
    * Note that before you can use it you can still load
    * hosts and do other things. As soon as you are ready to use
-   * it do not forget to call first ndpi_finalize_initalization()
+   * it do not forget to call first ndpi_finalize_initialization()
    *
    * You can call this function multiple times, (i.e. to create multiple
    * indipendent detection contexts) but all these calls MUST NOT run
@@ -198,12 +203,20 @@ extern "C" {
    * @par ndpi_str = the struct created for the protocol detection
    *
    */
-  void ndpi_finalize_initalization(struct ndpi_detection_module_struct *ndpi_str);
+  void ndpi_finalize_initialization(struct ndpi_detection_module_struct *ndpi_str);
 
   /**
-   * Frees the memory allocated in the specified flow
+   * Frees the dynamic memory allocated members in the specified flow
    *
-   * @par flow  = the flow to deallocate
+   * @par flow  = the flow struct which dynamic allocated members should be deallocated
+   *
+   */
+  void ndpi_free_flow_data(struct ndpi_flow_struct *flow);
+
+  /**
+   * Frees the dynamic memory allocated members in the specified flow and the flow struct itself
+   *
+   * @par flow  = the flow struct and its dynamic allocated members that should be deallocated
    *
    */
   void ndpi_free_flow(struct ndpi_flow_struct *flow);
@@ -263,7 +276,7 @@ extern "C" {
   void ndpi_set_protocol_detection_bitmask2(struct ndpi_detection_module_struct *ndpi_struct,
 					    const NDPI_PROTOCOL_BITMASK * detection_bitmask);
 
-    /**
+  /**
    *  Function to be called before we give up with detection for a given flow.
    *  This function reduces the NDPI_UNKNOWN_PROTOCOL detection
    *
@@ -351,7 +364,7 @@ extern "C" {
 				 struct ndpi_flow_struct *flow,
 				 NDPI_SELECTION_BITMASK_PROTOCOL_SIZE *ndpi_selection_packet);
 
-  
+
   /**
    * Query the pointer to the layer 4 packet
    *
@@ -362,7 +375,7 @@ extern "C" {
    * @par    l4_protocol_return = protocol of the layer 4 data if return value == 0, undefined otherwise
    * @par    flags = limit operation on ipv4 or ipv6 packets. Possible values: NDPI_DETECTION_ONLY_IPV4 - NDPI_DETECTION_ONLY_IPV6 - 0 (any)
    * @return 0 if layer 4 data could be found correctly;
-             else != 0
+   else != 0
    *
    */
   u_int8_t ndpi_detection_get_l4(const u_int8_t *l3, u_int16_t l3_len, const u_int8_t **l4_return, u_int16_t *l4_len_return,
@@ -412,7 +425,9 @@ extern "C" {
    * @par    string_to_match_len = the length of the string
    * @par    ret_match           = completed returned match information
    * @par    is_host_match       = value of the second field of struct ndpi_automa
-   * @return the ID of the matched subprotocol
+   * @return the ID of the matched subprotocol;
+   *         -1 if automa is not finalized;
+   *         -2 if automa==NULL or string_to_match==NULL or empty string_to_match
    *
    */
   int ndpi_match_string_subprotocol(struct ndpi_detection_module_struct *ndpi_struct,
@@ -439,6 +454,16 @@ extern "C" {
 					ndpi_protocol_match_result *ret_match,
 					u_int16_t master_protocol_id);
 
+  /**
+   * Check if the string content passed match with a protocol
+   *
+   * @par    ndpi_struct         = the detection module
+   * @par    flow                = the flow where match the host
+   * @par    subprotocol_id      = subprotocol id
+   */
+  void ndpi_check_subprotocol_risk(struct ndpi_detection_module_struct *ndpi_str,
+				 struct ndpi_flow_struct *flow, u_int16_t subprotocol_id);
+
   /**
    * Check if the string content passed match with a protocol
    *
@@ -466,9 +491,9 @@ extern "C" {
    *
    */
   void ndpi_exclude_protocol(struct ndpi_detection_module_struct *ndpi_struct,
-				  struct ndpi_flow_struct *flow,
-				  u_int16_t master_protocol_id,
-				  const char *_file, const char *_func,int _line);
+			     struct ndpi_flow_struct *flow,
+			     u_int16_t master_protocol_id,
+			     const char *_file, const char *_func,int _line);
   /**
    * Check if the string -bigram_to_match- match with a bigram of -automa-
    *
@@ -478,9 +503,7 @@ extern "C" {
    * @return  0
    *
    */
-  int ndpi_match_bigram(struct ndpi_detection_module_struct *ndpi_mod,
-			ndpi_automa *automa,
-			char *bigram_to_match);
+  int ndpi_match_bigram(const char *bigram_to_match);
 
   /**
    * Write the protocol name in the buffer -buf- as master_protocol.protocol
@@ -659,6 +682,13 @@ extern "C" {
    */
   void ndpi_dump_protocols(struct ndpi_detection_module_struct *mod);
 
+  /**
+   * Write the list of the scores and their associated risks
+   *
+   * @par  ndpi_mod = the detection module
+   */
+  void ndpi_dump_risks_score();
+
   /**
    * Read a file and load the protocols
    *
@@ -677,7 +707,29 @@ extern "C" {
   int ndpi_load_protocols_file(struct ndpi_detection_module_struct *ndpi_mod,
 			       const char* path);
 
- /**
+  /**
+   * Add an IP-address based risk mask
+   *
+   * @par     ndpi_mod = the detection module
+   * @par     ip       = the IP address for which you wanna set the mask
+   * @par     mask     = the IP risk mask
+   * @return  0 if the rule is loaded correctly;
+   *          -1 else
+   */
+  int ndpi_add_ip_risk_mask(struct ndpi_detection_module_struct *ndpi_mod, char *ip, ndpi_risk mask);
+
+  /**
+   * Add a host-address based risk mask
+   *
+   * @par     ndpi_mod = the detection module
+   * @par     host     = the hostname/domain for which you wanna set the mask
+   * @par     mask     = the host risk mask
+   * @return  0 if the rule is loaded correctly;
+   *          -1 else
+   */
+  int ndpi_add_host_risk_mask(struct ndpi_detection_module_struct *ndpi_mod, char *host, ndpi_risk mask);
+
+  /**
    * Read a file and load the categories
    *
    * @par     ndpi_mod = the detection module
@@ -687,6 +739,35 @@ extern "C" {
    */
   int ndpi_load_categories_file(struct ndpi_detection_module_struct *ndpi_str, const char* path);
 
+  /**
+   * Read a file and load the list of risky domains
+   *
+   * @par     ndpi_mod = the detection module
+   * @par     path     = the path of the file
+   * @return  0 if the file is loaded correctly;
+   *          -1 else
+   */
+  int ndpi_load_risk_domain_file(struct ndpi_detection_module_struct *ndpi_str, const char* path);
+
+  /**
+   * Read a file and load the list of malicious JA3 signatures
+   *
+   * @par     ndpi_mod = the detection module
+   * @par     path     = the path of the file
+   * @return  0 if the file is loaded correctly;
+   *          -1 else
+   */
+  int ndpi_load_malicious_ja3_file(struct ndpi_detection_module_struct *ndpi_str, const char *path);
+
+  /**
+   * Read a file and load the list of malicious SSL certificate SHA1 fingerprints.
+   * @par     ndpi_mod = the detection module
+   * @par     path     = the path of the file
+   * @return  0 if the file is loaded correctly;
+   *          -1 else
+   */
+  int ndpi_load_malicious_sha1_file(struct ndpi_detection_module_struct *ndpi_str, const char *path);
+
   /**
    * Get the total number of the supported protocols
    *
@@ -714,7 +795,7 @@ extern "C" {
   void ndpi_set_automa(struct ndpi_detection_module_struct *ndpi_struct,
 		       void* automa);
 
-/* NDPI_PROTOCOL_HTTP */
+  /* NDPI_PROTOCOL_HTTP */
   /**
    * Retrieve information for HTTP flows
    *
@@ -722,7 +803,7 @@ extern "C" {
    * @par     flow     = the detected flow
    * @return  the HTTP method information about the flow
    *
-  */
+   */
   ndpi_http_method ndpi_get_http_method(struct ndpi_detection_module_struct *ndpi_mod,
 					struct ndpi_flow_struct *flow);
 
@@ -733,7 +814,7 @@ extern "C" {
    * @par     flow     = the detected flow
    * @return  the HTTP method information about the flow
    *
-  */
+   */
   char* ndpi_get_http_url(struct ndpi_detection_module_struct *ndpi_mod,
 			  struct ndpi_flow_struct *flow);
 
@@ -744,11 +825,11 @@ extern "C" {
    * @par     flow     = the detected flow
    * @return  the HTTP method information about the flow
    *
-  */
+   */
   char* ndpi_get_http_content_type(struct ndpi_detection_module_struct *ndpi_mod,
 				   struct ndpi_flow_struct *flow);
 
-/* NDPI_PROTOCOL_TOR */
+  /* NDPI_PROTOCOL_TOR */
   /**
    * Check if the flow could be detected as TOR protocol
    *
@@ -783,7 +864,7 @@ extern "C" {
    * Add a string to match to an automata
    *
    * @par     The automata initialized with ndpi_init_automa();
-   * @par     The (sub)string to search
+   * @par     The (sub)string to search (malloc'ed memory)
    * @par     The number associated with this string
    * @return  0 in case of no error, or -1 if an error occurred.
    *
@@ -794,7 +875,7 @@ extern "C" {
    * Add a string to match to an automata. Same as ndpi_add_string_value_to_automa() with num set to 1
    *
    * @par     The automata initialized with ndpi_init_automa();
-   * @par     The (sub)string to search
+   * @par     The (sub)string to search (malloc'ed memory)
    * @return  0 in case of no error, or -1 if an error occurred.
    *
    */
@@ -819,16 +900,16 @@ extern "C" {
   int ndpi_match_string(void *_automa, char *string_to_match);
 
   int ndpi_load_ip_category(struct ndpi_detection_module_struct *ndpi_struct,
-				 const char *ip_address_and_mask, ndpi_protocol_category_t category);
+			    const char *ip_address_and_mask, ndpi_protocol_category_t category);
   int ndpi_load_hostname_category(struct ndpi_detection_module_struct *ndpi_struct,
-				 const char *name_to_add, ndpi_protocol_category_t category);
+				  const char *name_to_add, ndpi_protocol_category_t category);
   int ndpi_load_category(struct ndpi_detection_module_struct *ndpi_struct,
-				 const char *ip_or_name, ndpi_protocol_category_t category);
+			 const char *ip_or_name, ndpi_protocol_category_t category);
   int ndpi_enable_loaded_categories(struct ndpi_detection_module_struct *ndpi_struct);
   int ndpi_fill_ip_protocol_category(struct ndpi_detection_module_struct *ndpi_struct,
-				 u_int32_t saddr,
-				 u_int32_t daddr,
-				 ndpi_protocol *ret);
+				     u_int32_t saddr,
+				     u_int32_t daddr,
+				     ndpi_protocol *ret);
   int ndpi_match_custom_category(struct ndpi_detection_module_struct *ndpi_struct,
 				 char *name, u_int name_len, ndpi_protocol_category_t *id);
   void ndpi_fill_protocol_category(struct ndpi_detection_module_struct *ndpi_struct,
@@ -845,6 +926,9 @@ extern "C" {
   ndpi_l4_proto_info ndpi_get_l4_proto_info(struct ndpi_detection_module_struct *ndpi_struct, u_int16_t ndpi_proto_id);
   const char* ndpi_get_l4_proto_name(ndpi_l4_proto_info proto);
 
+  u_int16_t ndpi_get_lower_proto(ndpi_protocol proto);
+  u_int16_t ndpi_get_upper_proto(ndpi_protocol proto);
+
   ndpi_proto_defaults_t* ndpi_get_proto_defaults(struct ndpi_detection_module_struct *ndpi_mod);
   u_int ndpi_get_ndpi_num_supported_protocols(struct ndpi_detection_module_struct *ndpi_mod);
   u_int ndpi_get_ndpi_num_custom_protocols(struct ndpi_detection_module_struct *ndpi_mod);
@@ -881,9 +965,6 @@ extern "C" {
   void set_ndpi_flow_free(void  (*__ndpi_flow_free)(void *ptr));
   void set_ndpi_debug_function(struct ndpi_detection_module_struct *ndpi_str,
 			       ndpi_debug_function_ptr ndpi_debug_printf);
-  //void * ndpi_malloc(size_t size);
-  //void * ndpi_calloc(unsigned long count, size_t size);
-  //void ndpi_free(void *ptr);
   u_int16_t ndpi_get_api_version(void);
   const char *ndpi_get_gcrypt_version(void);
 
@@ -904,8 +985,12 @@ extern "C" {
 				      char *buffer, u_int buffer_size,
 				      u_int8_t min_string_match_len, /* Will return 0 if no string > min_string_match_len have been found */
 				      char *outbuf, u_int outbuf_len);
+  /* Return a flow info string (summarized). Does only work for DNS/HTTP/TLS/QUIC. */
+  const char* ndpi_get_flow_info(struct ndpi_flow_struct const * const flow,
+                                 ndpi_protocol const * const l7_protocol);
   char* ndpi_ssl_version2str(struct ndpi_flow_struct *flow,
                              u_int16_t version, u_int8_t *unknown_tls_version);
+  int ndpi_netbios_name_interpret(u_char *in, u_int in_len, u_char *out, u_int out_len);
   void ndpi_patchIPv6Address(char *str);
   void ndpi_user_pwd_payload_copy(u_int8_t *dest, u_int dest_len, u_int offset,
 				  const u_int8_t *src, u_int src_len);
@@ -930,20 +1015,48 @@ extern "C" {
 		     ndpi_serializer *serializer);
 
   void ndpi_md5(const u_char *data, size_t data_len, u_char hash[16]);
+  u_int32_t ndpi_quick_hash(unsigned char *str, u_int str_len);
 
   const char* ndpi_http_method2str(ndpi_http_method m);
-  ndpi_http_method ndpi_http_str2method(const char* method, ssize_t method_len);
-  
-  /* ptree (trie) API */
+  ndpi_http_method ndpi_http_str2method(const char* method, u_int16_t method_len);
+
+  /* Utility functions to fill prefix (used by the patricia tree) */
+  int ndpi_fill_prefix_v4(ndpi_prefix_t *p, const struct in_addr *a, int b, int mb);
+  int ndpi_fill_prefix_v6(ndpi_prefix_t *prefix, const struct in6_addr *addr, int bits, int maxbits);
+  int ndpi_fill_prefix_mac(ndpi_prefix_t *prefix, u_int8_t *mac, int bits, int maxbits);
+
+  /* Patricia tree API (radix tree supporting IPv4/IPv6/MAC) */
+  ndpi_patricia_tree_t *ndpi_patricia_new(u_int16_t maxbits);
+  ndpi_patricia_tree_t *ndpi_patricia_clone (const ndpi_patricia_tree_t * const from);
+  void ndpi_patricia_destroy(ndpi_patricia_tree_t *patricia, ndpi_void_fn_t func);
+
+  ndpi_patricia_node_t *ndpi_patricia_search_exact(ndpi_patricia_tree_t *patricia, ndpi_prefix_t *prefix);
+  ndpi_patricia_node_t *ndpi_patricia_search_best(ndpi_patricia_tree_t *patricia, ndpi_prefix_t *prefix);
+  ndpi_patricia_node_t *ndpi_patricia_lookup(ndpi_patricia_tree_t *patricia, ndpi_prefix_t *prefix);
+  size_t ndpi_patricia_walk_tree_inorder(ndpi_patricia_tree_t *patricia, ndpi_void_fn3_t func, void *data);
+  size_t ndpi_patricia_walk_inorder(ndpi_patricia_node_t *node, ndpi_void_fn3_t func, void *data);
+  void ndpi_patricia_remove(ndpi_patricia_tree_t *patricia, ndpi_patricia_node_t *node);
+
+  void ndpi_patricia_set_node_u64(ndpi_patricia_node_t *node, u_int64_t value);
+  u_int64_t ndpi_patricia_get_node_u64(ndpi_patricia_node_t *node);
+  void ndpi_patricia_set_node_data(ndpi_patricia_node_t *node, void *data);
+  void *ndpi_patricia_get_node_data(ndpi_patricia_node_t *node);
+  ndpi_prefix_t *ndpi_patricia_get_node_prefix(ndpi_patricia_node_t *node);
+  u_int16_t ndpi_patricia_get_node_bits(ndpi_patricia_node_t *node);
+  u_int16_t ndpi_patricia_get_maxbits(ndpi_patricia_tree_t *tree);
+
+  /* ptree (trie) API - a wrapper on top of Patricia that seamlessly handle IPv4 and IPv6 */
   ndpi_ptree_t* ndpi_ptree_create(void);
-  int ndpi_ptree_insert(ndpi_ptree_t *tree, const ndpi_ip_addr_t *addr, u_int8_t bits, u_int32_t user_data);
-  int ndpi_ptree_match_addr(ndpi_ptree_t *tree, const ndpi_ip_addr_t *addr, u_int32_t *user_data);
+  int ndpi_ptree_insert(ndpi_ptree_t *tree, const ndpi_ip_addr_t *addr, u_int8_t bits, u_int64_t user_data);
+  int ndpi_ptree_match_addr(ndpi_ptree_t *tree, const ndpi_ip_addr_t *addr, u_int64_t *user_data);
   void ndpi_ptree_destroy(ndpi_ptree_t *tree);
 
   /* General purpose utilities */
   u_int64_t ndpi_htonll(u_int64_t v);
   u_int64_t ndpi_ntohll(u_int64_t v);
-
+  u_int8_t ndpi_is_valid_protoId(u_int16_t protoId);
+  u_int8_t ndpi_is_encrypted_proto(struct ndpi_detection_module_struct *ndpi_str, ndpi_protocol proto);
+  
   /* DGA */
   int ndpi_check_dga_name(struct ndpi_detection_module_struct *ndpi_str,
 			  struct ndpi_flow_struct *flow,
@@ -953,7 +1066,7 @@ extern "C" {
 
   /**
    * Initialize a serializer handle (allocated by the caller).
-   * @param serializer The serializer handle 
+   * @param serializer The serializer handle
    * @param fmt The serialization format (ndpi_serialization_format_json, ndpi_serialization_format_tlv, ndpi_serialization_format_csv)
    * @return 0 on success, a negative number otherwise
    */
@@ -961,28 +1074,28 @@ extern "C" {
 
   /**
    * Initialize a serializer handle. Same as ndpi_init_serializer, but with some low-level settings.
-   * @param serializer The serializer handle 
+   * @param serializer The serializer handle
    * @param fmt The serialization format (ndpi_serialization_format_json, ndpi_serialization_format_tlv, ndpi_serialization_format_csv)
    * @param buffer_size The initial internal buffer_size
-   * @return 0 on success, a negative number otherwise 
+   * @return 0 on success, a negative number otherwise
    */
   int ndpi_init_serializer_ll(ndpi_serializer *serializer, ndpi_serialization_format fmt, u_int32_t buffer_size);
 
   /**
    * Release all allocated data structure.
-   * @param serializer The serializer handle 
+   * @param serializer The serializer handle
    */
   void ndpi_term_serializer(ndpi_serializer *serializer);
 
   /**
    * Reset the serializer (cleanup the internal buffer to start a new serialization)
-   * @param serializer The serializer handle 
+   * @param serializer The serializer handle
    */
   void ndpi_reset_serializer(ndpi_serializer *serializer);
 
   /**
    * Serialize a 32-bit unsigned int key and a 32-bit unsigned int value
-   * @param serializer The serializer handle 
+   * @param serializer The serializer handle
    * @param key The field name or ID
    * @param value The field value
    * @return 0 on success, a negative number otherwise
@@ -990,8 +1103,8 @@ extern "C" {
   int ndpi_serialize_uint32_uint32(ndpi_serializer *serializer, u_int32_t key, u_int32_t value);
 
   /**
-   * Serialize a 32-bit unsigned int key and a 64-bit unsigned int value 
-   * @param serializer The serializer handle 
+   * Serialize a 32-bit unsigned int key and a 64-bit unsigned int value
+   * @param serializer The serializer handle
    * @param key The field name or ID
    * @param value The field value
    * @return 0 on success, a negative number otherwise
@@ -1000,7 +1113,7 @@ extern "C" {
 
   /**
    * Serialize a 32-bit unsigned int key and a 32-bit signed int value
-   * @param serializer The serializer handle 
+   * @param serializer The serializer handle
    * @param key The field name or ID
    * @param value The field value
    * @return 0 on success, a negative number otherwise
@@ -1009,7 +1122,7 @@ extern "C" {
 
   /**
    * Serialize a 32-bit unsigned int key and a 64-bit signed int value
-   * @param serializer The serializer handle 
+   * @param serializer The serializer handle
    * @param key The field name or ID
    * @param value The field value
    * @return 0 on success, a negative number otherwise
@@ -1018,7 +1131,7 @@ extern "C" {
 
   /**
    * Serialize a 32-bit unsigned int key and a float value
-   * @param serializer The serializer handle 
+   * @param serializer The serializer handle
    * @param key The field name or ID
    * @param value The field value
    * @param format The float value format
@@ -1028,7 +1141,7 @@ extern "C" {
 
   /**
    * Serialize a 32-bit unsigned int key and a string value
-   * @param serializer The serializer handle 
+   * @param serializer The serializer handle
    * @param key The field name or ID
    * @param value The field value
    * @return 0 on success, a negative number otherwise
@@ -1037,7 +1150,7 @@ extern "C" {
 
   /**
    * Serialize a 32-bit unsigned int key and a boolean value
-   * @param serializer The serializer handle 
+   * @param serializer The serializer handle
    * @param key The field name or ID
    * @param value The field value
    * @return 0 on success, a negative number otherwise
@@ -1046,7 +1159,7 @@ extern "C" {
 
   /**
    * Serialize an unterminated string key and a 32-bit signed int value
-   * @param serializer The serializer handle 
+   * @param serializer The serializer handle
    * @param key The field name or ID
    * @param klen The key length
    * @param value The field value
@@ -1056,7 +1169,7 @@ extern "C" {
 
   /**
    * Serialize a string key and a 32-bit signed int value
-   * @param serializer The serializer handle 
+   * @param serializer The serializer handle
    * @param key The field name or ID
    * @param value The field value
    * @return 0 on success, a negative number otherwise
@@ -1065,7 +1178,7 @@ extern "C" {
 
   /**
    * Serialize an unterminated string key and a 64-bit signed int value
-   * @param serializer The serializer handle 
+   * @param serializer The serializer handle
    * @param key The field name or ID
    * @param klen The key length
    * @param value The field value
@@ -1075,7 +1188,7 @@ extern "C" {
 
   /**
    * Serialize a string key and a 64-bit signed int value
-   * @param serializer The serializer handle 
+   * @param serializer The serializer handle
    * @param key The field name or ID
    * @param value The field value
    * @return 0 on success, a negative number otherwise
@@ -1084,7 +1197,7 @@ extern "C" {
 
   /**
    * Serialize an unterminated string key and a 32-bit unsigned int value
-   * @param serializer The serializer handle 
+   * @param serializer The serializer handle
    * @param key The field name or ID
    * @param klen The key length
    * @param value The field value
@@ -1094,7 +1207,7 @@ extern "C" {
 
   /**
    * Serialize a string key and a 32-bit unsigned int value
-   * @param serializer The serializer handle 
+   * @param serializer The serializer handle
    * @param key The field name or ID
    * @param value The field value
    * @return 0 on success, a negative number otherwise
@@ -1103,7 +1216,7 @@ extern "C" {
 
   /**
    * Serialize a string key and a float value
-   * @param serializer The serializer handle 
+   * @param serializer The serializer handle
    * @param key The field name or ID
    * @param value The field value
    * @param format The float format
@@ -1113,7 +1226,7 @@ extern "C" {
 
   /**
    * Serialize an unterminated string key and a 64-bit unsigned int value
-   * @param serializer The serializer handle 
+   * @param serializer The serializer handle
    * @param key The field name or ID
    * @param klen The key length
    * @param value The field value
@@ -1123,7 +1236,7 @@ extern "C" {
 
   /**
    * Serialize a string key and a 64-bit unsigned int value
-   * @param serializer The serializer handle 
+   * @param serializer The serializer handle
    * @param key The field name or ID
    * @param value The field value
    * @return 0 on success, a negative number otherwise
@@ -1132,7 +1245,7 @@ extern "C" {
 
   /**
    * Serialize an unterminated string key and an unterminated string value
-   * @param serializer The serializer handle 
+   * @param serializer The serializer handle
    * @param key The field name or ID
    * @param klen The key length
    * @param value The field value
@@ -1143,7 +1256,7 @@ extern "C" {
 
   /**
    * Serialize a string key and a string value
-   * @param serializer The serializer handle 
+   * @param serializer The serializer handle
    * @param key The field name or ID
    * @param value The field value
    * @return 0 on success, a negative number otherwise
@@ -1152,7 +1265,7 @@ extern "C" {
 
   /**
    * Serialize a string key and an unterminated string value
-   * @param serializer The serializer handle 
+   * @param serializer The serializer handle
    * @param key The field name or ID
    * @param value The field value
    * @param vlen The value length
@@ -1162,7 +1275,7 @@ extern "C" {
 
   /**
    * Serialize a string key and a raw value (this is a string which is added to the JSON without any quote or escaping)
-   * @param serializer The serializer handle 
+   * @param serializer The serializer handle
    * @param key The field name or ID
    * @param value The field value
    * @param vlen The value length
@@ -1172,7 +1285,7 @@ extern "C" {
 
   /**
    * Serialize an unterminated string key and a float value
-   * @param serializer The serializer handle 
+   * @param serializer The serializer handle
    * @param key The field name or ID
    * @param klen The key length
    * @param value The field value
@@ -1182,8 +1295,8 @@ extern "C" {
   int ndpi_serialize_binary_float(ndpi_serializer *_serializer, const char *key, u_int16_t klen, float value, const char *format /* e.f. "%.2f" */);
 
   /**
-   * Serialize a string key and a a float value 
-   * @param serializer The serializer handle 
+   * Serialize a string key and a a float value
+   * @param serializer The serializer handle
    * @param key The field name or ID
    * @param value The field value
    * @param format The float format
@@ -1192,8 +1305,18 @@ extern "C" {
   int ndpi_serialize_string_float(ndpi_serializer *serializer, const char *key, float value, const char *format /* e.f. "%.2f" */);
 
   /**
-   * Serialize a string key and a boolean value
-   * @param serializer The serializer handle 
+   * Serialize an unterminated string key and a boolean value (JSON/CSV only, not supported by TLV)
+   * @param serializer The serializer handle
+   * @param key The field name or ID
+   * @param klen The key length
+   * @param value The field value
+   * @return 0 on success, a negative number otherwise
+   */
+  int ndpi_serialize_binary_boolean(ndpi_serializer *_serializer, const char *key, u_int16_t klen, u_int8_t value);
+
+  /**
+   * Serialize a string key and a boolean value (JSON/CSV only, not supported by TLV)
+   * @param serializer The serializer handle
    * @param key The field name or ID
    * @param value The field value
    * @return 0 on success, a negative number otherwise
@@ -1202,7 +1325,7 @@ extern "C" {
 
   /**
    * Serialize a raw record in an array (this is a low-level function and its use is not recommended)
-   * @param serializer The serializer handle 
+   * @param serializer The serializer handle
    * @param record The record value
    * @param record_len The record length
    * @return 0 on success, a negative number otherwise
@@ -1212,15 +1335,15 @@ extern "C" {
   /**
    * Serialize an End-Of-Record (the current object becomes is terminated and added to an array,
    * and a new object is created where the next items will be added)
-   * @param serializer The serializer handle 
+   * @param serializer The serializer handle
    * @return 0 on success, a negative number otherwise
    */
   int ndpi_serialize_end_of_record(ndpi_serializer *serializer);
 
   /**
-   * Serialize the start of a list with an unterminated string key, where the next serialized items 
+   * Serialize the start of a list with an unterminated string key, where the next serialized items
    * will be added (note: keys for the new items are ignored)
-   * @param serializer The serializer handle 
+   * @param serializer The serializer handle
    * @param key The field name or ID
    * @param klen The key length
    * @return 0 on success, a negative number otherwise
@@ -1230,7 +1353,7 @@ extern "C" {
   /**
    * Serialize the start of a list, where the next serialized items will be added (note: keys for
    * the new items are ignored)
-   * @param serializer The serializer handle 
+   * @param serializer The serializer handle
    * @param key The field name or ID
    * @param value The field value
    * @return 0 on success, a negative number otherwise
@@ -1239,14 +1362,14 @@ extern "C" {
 
   /**
    * Serialize the end of a list
-   * @param serializer The serializer handle 
+   * @param serializer The serializer handle
    * @return 0 on success, a negative number otherwise
    */
   int ndpi_serialize_end_of_list(ndpi_serializer *serializer);
 
   /**
-   * Serialize the start of a block with an unterminated string key 
-   * @param serializer The serializer handle 
+   * Serialize the start of a block with an unterminated string key
+   * @param serializer The serializer handle
    * @param key The field name or ID
    * @param klen The key length
    * @return 0 on success, a negative number otherwise
@@ -1254,16 +1377,16 @@ extern "C" {
   int ndpi_serialize_start_of_block_binary(ndpi_serializer *_serializer, const char *key, u_int16_t klen);
 
   /**
-   * Serialize the start of a block with a string key 
-   * @param serializer The serializer handle 
+   * Serialize the start of a block with a string key
+   * @param serializer The serializer handle
    * @param key The field name or ID
    * @return 0 on success, a negative number otherwise
    */
   int ndpi_serialize_start_of_block(ndpi_serializer *serializer, const char *key);
 
   /**
-   * Serialize the end of a block 
-   * @param serializer The serializer handle 
+   * Serialize the end of a block
+   * @param serializer The serializer handle
    * @param key The field name or ID
    * @param value The field value
    * @return 0 on success, a negative number otherwise
@@ -1272,7 +1395,7 @@ extern "C" {
 
   /**
    * Return the serialized buffer
-   * @param serializer The serializer handle 
+   * @param serializer The serializer handle
    * @param buffer_len The buffer length (out)
    * @return The buffer
    */
@@ -1280,7 +1403,7 @@ extern "C" {
 
   /**
    * Return the current serialized buffer length
-   * @param serializer The serializer handle 
+   * @param serializer The serializer handle
    * @return The buffer length
    */
   u_int32_t ndpi_serializer_get_buffer_len(ndpi_serializer *serializer);
@@ -1294,29 +1417,29 @@ extern "C" {
 
   /**
    * Change the serializer buffer length
-   * @param serializer The serializer handle 
-   * @param l The new buffer length 
+   * @param serializer The serializer handle
+   * @param l The new buffer length
    * @return 0 on success, a negative number otherwise
    */
   int ndpi_serializer_set_buffer_len(ndpi_serializer *serializer, u_int32_t l);
 
   /**
    * Return the configured serialization format
-   * @param serializer The serializer handle 
+   * @param serializer The serializer handle
    * @return The serialization format
    */
   ndpi_serialization_format ndpi_serializer_get_format(ndpi_serializer *serializer);
 
   /**
    * Set the CSV separator
-   * @param serializer The serializer handle 
+   * @param serializer The serializer handle
    * @param separator The separator
    */
   void ndpi_serializer_set_csv_separator(ndpi_serializer *serializer, char separator);
 
   /**
    * Return the header automatically built from keys (CSV only)
-   * @param serializer The serializer handle 
+   * @param serializer The serializer handle
    * @param buffer_len The buffer length (out)
    * @return The header
    */
@@ -1324,13 +1447,13 @@ extern "C" {
 
   /**
    * Create a snapshot of the internal buffer for later rollback (ndpi_serializer_rollback_snapshot)
-   * @param serializer The serializer handle 
+   * @param serializer The serializer handle
    */
   void ndpi_serializer_create_snapshot(ndpi_serializer *serializer);
 
   /**
    * Rollback to the latest snapshot
-   * @param serializer The serializer handle 
+   * @param serializer The serializer handle
    */
   void ndpi_serializer_rollback_snapshot(ndpi_serializer *serializer);
 
@@ -1362,7 +1485,7 @@ extern "C" {
   /* Data analysis */
   struct ndpi_analyze_struct* ndpi_alloc_data_analysis(u_int16_t _max_series_len);
   void ndpi_init_data_analysis(struct ndpi_analyze_struct *s, u_int16_t _max_series_len);
-  void ndpi_free_data_analysis(struct ndpi_analyze_struct *d);
+  void ndpi_free_data_analysis(struct ndpi_analyze_struct *d, u_int8_t free_pointer);
   void ndpi_reset_data_analysis(struct ndpi_analyze_struct *d);
   void ndpi_data_add_value(struct ndpi_analyze_struct *s, const u_int32_t value);
 
@@ -1381,6 +1504,37 @@ extern "C" {
   u_int32_t ndpi_data_max(struct ndpi_analyze_struct *s);
   float ndpi_data_ratio(u_int32_t sent, u_int32_t rcvd);
 
+  /* ******************************* */
+
+  int ndpi_alloc_rsi(struct ndpi_rsi_struct *s, u_int16_t num_learning_values);
+  void  ndpi_free_rsi(struct ndpi_rsi_struct *s);
+  float ndpi_rsi_add_value(struct ndpi_rsi_struct *s, const u_int32_t value);
+
+  /* ******************************* */
+
+  int  ndpi_hw_init(struct ndpi_hw_struct *hw, u_int16_t num_periods, u_int8_t additive_seeasonal,
+		    double alpha, double beta, double gamma, float significance);
+  void ndpi_hw_free(struct ndpi_hw_struct *hw);
+  int  ndpi_hw_add_value(struct ndpi_hw_struct *hw, const u_int64_t value, double *forecast,  double *confidence_band);
+
+  /* ******************************* */
+
+  int ndpi_ses_init(struct ndpi_ses_struct *ses, double alpha, float significance);
+  int ndpi_ses_add_value(struct ndpi_ses_struct *ses, const u_int64_t _value, double *forecast, double *confidence_band);
+
+  /* ******************************* */
+
+  int ndpi_des_init(struct ndpi_des_struct *des, double alpha, double beta, float significance);
+  int ndpi_des_add_value(struct ndpi_des_struct *des, const u_int64_t _value, double *forecast, double *confidence_band);
+
+  /* ******************************* */
+
+  int   ndpi_jitter_init(struct ndpi_jitter_struct *hw, u_int16_t num_periods);
+  void  ndpi_jitter_free(struct ndpi_jitter_struct *hw);
+  float ndpi_jitter_add_value(struct ndpi_jitter_struct *s, const float value);
+
+  /* ******************************* */
+
   const char* ndpi_data_ratio2str(float ratio);
 
   void ndpi_data_print_window_values(struct ndpi_analyze_struct *s); /* debug */
@@ -1392,6 +1546,10 @@ extern "C" {
   void ndpi_serialize_risk(ndpi_serializer *serializer, struct ndpi_flow_struct *flow);
 
   const char* ndpi_risk2str(ndpi_risk_enum risk);
+  const char* ndpi_severity2str(ndpi_risk_severity s);
+  ndpi_risk_info* ndpi_risk2severity(ndpi_risk_enum risk);
+  u_int16_t ndpi_risk2score(ndpi_risk risk,
+			    u_int16_t *client_score, u_int16_t *server_score);
 
   /* ******************************* */
 
@@ -1401,7 +1559,7 @@ extern "C" {
   int ndpi_hll_init(struct ndpi_hll *hll, u_int8_t bits);
   void ndpi_hll_destroy(struct ndpi_hll *hll);
   void ndpi_hll_reset(struct ndpi_hll *hll);
-  
+
   /* Add values */
   void ndpi_hll_add(struct ndpi_hll *hll, const char *data, size_t data_len);
   void ndpi_hll_add_number(struct ndpi_hll *hll, u_int32_t value) ;
@@ -1425,7 +1583,34 @@ extern "C" {
 			u_int8_t num_clusters, u_int16_t *cluster_ids,
 			struct ndpi_bin *centroids);
 
+  /* ******************************* */
+
   u_int32_t ndpi_quick_16_byte_hash(u_int8_t *in_16_bytes_long);
+
+  /* ******************************* */
+
+  ndpi_str_hash* ndpi_hash_alloc(u_int32_t max_num_entries);
+  void ndpi_hash_free(ndpi_str_hash *h);
+  int ndpi_hash_find_entry(ndpi_str_hash *h, char *key, u_int key_len, u_int8_t *value);
+  int ndpi_hash_add_entry(ndpi_str_hash *h, char *key, u_int8_t key_len, u_int8_t value);
+
+  /* ******************************* */
+
+  int ndpi_load_geoip(struct ndpi_detection_module_struct *ndpi_str,
+		      const char *ip_city_data, const char *ip_as_data);
+  void ndpi_free_geoip(struct ndpi_detection_module_struct *ndpi_str);
+  int ndpi_get_geoip_asn(struct ndpi_detection_module_struct *ndpi_str,
+			 char *ip, u_int32_t *asn);
+  int ndpi_get_geoip_country_continent(struct ndpi_detection_module_struct *ndpi_str, char *ip,
+				       char *country_code, u_int8_t country_code_len,
+				       char *continent, u_int8_t continent_len);
+
+  /* ******************************* */
+
+  char* ndpi_get_flow_name(struct ndpi_flow_struct *flow);
+  
+  /* ******************************* */
+  
 #ifdef __cplusplus
 }
 #endif
