@@ -1,8 +1,5 @@
 #define COMPILE_DL_CURL 1
 #define HAVE_CURL 1
-#define HAVE_CURL_EASY_STRERROR 1
-#define HAVE_CURL_MULTI_STRERROR 1
-#define HAVE_CURL_SSL 1
 #define HAVE_DLFCN_H 1
 #define HAVE_INTTYPES_H 1
 #define HAVE_MEMORY_H 1
