@@ -1,5 +1,4 @@
 #define COMPILE_DL_XDEBUG 1
-#define HAVE_CLOCK_GETTIME 1
 #define HAVE_DLFCN_H 1
 #define HAVE_GETTIMEOFDAY 1
 #define HAVE_INTTYPES_H 1
@@ -15,3 +14,5 @@
 #define HAVE_SYS_TYPES_H 1
 #define HAVE_UNISTD_H 1
 #define HAVE_XDEBUG 1
+#define HAVE_XDEBUG_CLOCK_GETTIME 1
+#define HAVE_XDEBUG_CLOCK_GETTIME_NSEC_NP 0
