@@ -142,12 +142,6 @@ options:
         description: The tag value.
         type: str
 
-  refresh_token:
-    required: true
-    description:
-    - The refresh token for NetApp Cloud Manager API operations.
-    type: str
-
 notes:
 - Support check_mode.
 '''
@@ -185,7 +179,7 @@ EXAMPLES = """
 
 RETURN = """
 ids:
-  description: Newly created Azure client ID in cloud manager, instance ID and account ID.
+  description: Newly created AWS client ID in cloud manager, instance ID and account ID.
   type: dict
   returned: success
 """
@@ -210,8 +204,6 @@ except ImportError as exc:
     HAS_AWS_LIB = False
     IMPORT_EXCEPTION = exc
 
-CLOUD_MANAGER_HOST = "cloudmanager.cloud.netapp.com"
-AWS_ACCOUNT = '952013314444'
 UUID = str(uuid.uuid4())
 
 
@@ -253,6 +245,8 @@ class NetAppCloudManagerConnectorAWS(object):
                 ['state', 'present', ['company', 'iam_instance_profile_name', 'key_name', 'security_group_ids', 'subnet_id']],
                 ['state', 'absent', ['instance_id', 'client_id', 'account_id']]
             ],
+            required_one_of=[['refresh_token', 'sa_client_id']],
+            required_together=[['sa_client_id', 'sa_secret_key']],
             supports_check_mode=True
         )
 
@@ -313,12 +307,12 @@ class NetAppCloudManagerConnectorAWS(object):
                     {
                         'Name': 'name',
                         'Values': [
-                            'Setup-As-Service-AMI-Prod*',
+                            self.rest_api.environment_data['AMI_FILTER'],
                         ]
                     },
                 ],
                 Owners=[
-                    AWS_ACCOUNT,
+                    self.rest_api.environment_data['AWS_ACCOUNT'],
                 ],
             )
         except ClientError as error:
@@ -418,7 +412,7 @@ class NetAppCloudManagerConnectorAWS(object):
         time.sleep(120)
         retries = 16
         while retries > 0:
-            occm_resp, error = self.na_helper.check_occm_status(CLOUD_MANAGER_HOST, self.rest_api, client_id)
+            occm_resp, error = self.na_helper.check_occm_status(self.rest_api.environment_data['CLOUD_MANAGER_HOST'], self.rest_api, client_id)
             if error is not None:
                 self.module.fail_json(
                     msg="Error: Not able to get occm status: %s, %s" % (str(error), str(occm_resp)))
@@ -460,7 +454,7 @@ class NetAppCloudManagerConnectorAWS(object):
         vpc = self.get_vpc()
 
         if self.parameters.get('account_id') is None:
-            response, error = self.na_helper.get_account(CLOUD_MANAGER_HOST, self.rest_api)
+            response, error = self.na_helper.get_account(self.rest_api.environment_data['CLOUD_MANAGER_HOST'], self.rest_api)
             if error is not None:
                 self.module.fail_json(
                     msg="Error: unexpected response on getting account: %s, %s" % (str(error), str(response)))
@@ -489,7 +483,7 @@ class NetAppCloudManagerConnectorAWS(object):
             }
         }
 
-        register_api = '%s/agents-mgmt/connector-setup' % CLOUD_MANAGER_HOST
+        register_api = '%s/agents-mgmt/connector-setup' % self.rest_api.environment_data['CLOUD_MANAGER_HOST']
         response, error, dummy = self.rest_api.post(register_api, body, header=headers)
         if error is not None:
             self.module.fail_json(msg="Error: unexpected response on getting userdata for connector setup: %s, %s" % (str(error), str(response)))
@@ -547,7 +541,8 @@ class NetAppCloudManagerConnectorAWS(object):
 
         retries = 30
         while retries > 0:
-            occm_resp, error = self.na_helper.check_occm_status(CLOUD_MANAGER_HOST, self.rest_api, self.parameters['client_id'])
+            occm_resp, error = self.na_helper.check_occm_status(self.rest_api.environment_data['CLOUD_MANAGER_HOST'],
+                                                                self.rest_api, self.parameters['client_id'])
             if error is not None:
                 self.module.fail_json(
                     msg="Error: Not able to get occm status: %s, %s" % (str(error), str(occm_resp)))
@@ -560,7 +555,8 @@ class NetAppCloudManagerConnectorAWS(object):
             # Taking too long for terminating OCCM
             return self.module.fail_json(msg="Taking too long for instance to finish terminating")
 
-        delete_occum_url = "%s/agents-mgmt/agent/%sclients" % (CLOUD_MANAGER_HOST, self.parameters['client_id'])
+        client = self.rest_api.format_cliend_id(self.parameters['client_id'])
+        delete_occum_url = "%s/agents-mgmt/agent/%s" % (self.rest_api.environment_data['CLOUD_MANAGER_HOST'], client)
         headers = {
             "X-User-Token": self.rest_api.token_type + " " + self.rest_api.token,
             "X-Tenancy-Account-Id": self.parameters['account_id']
