@@ -1,7 +1,7 @@
 #!/usr/local/bin/bash
 
 #The health directory to put the alarms
-HEALTHDIR="/usr/local/etc/netdata/health.d/"
+HEALTHDIR="/etc/netdata/health.d/"
 
 #the current time
 OUTDIR="alarms"
@@ -85,4 +85,4 @@ process_data "foreach_with_template" 10 "$HEALTHDIR/dim_foreach_with_template_sp
 rm "$HEALTHDIR/dim_foreach_with_template_sp.conf"
 rm -rf "$OUTDIR"
 
-echo  -e "${GREEN} all the tests were sucessful ${NOCOLOR}"
+echo  -e "${GREEN} all the tests were successful ${NOCOLOR}"
