@@ -1,31 +1,29 @@
 <?php
 
-/**
- *    Copyright (C) 2015 Deciso B.V.
+/*
+ * Copyright (C) 2015 Deciso B.V.
+ * All rights reserved.
  *
- *    All rights reserved.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
  *
- *    Redistribution and use in source and binary forms, with or without
- *    modification, are permitted provided that the following conditions are met:
+ * 1. Redistributions of source code must retain the above copyright notice,
+ *    this list of conditions and the following disclaimer.
  *
- *    1. Redistributions of source code must retain the above copyright notice,
- *       this list of conditions and the following disclaimer.
- *
- *    2. Redistributions in binary form must reproduce the above copyright
- *       notice, this list of conditions and the following disclaimer in the
- *       documentation and/or other materials provided with the distribution.
- *
- *    THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES,
- *    INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
- *    AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
- *    AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
- *    OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
- *    SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
- *    INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
- *    CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
- *    ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
- *    POSSIBILITY OF SUCH DAMAGE.
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
  *
+ * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES,
+ * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
+ * AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
+ * AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
+ * OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+ * POSSIBILITY OF SUCH DAMAGE.
  */
 
 namespace OPNsense\Auth;
@@ -144,14 +142,15 @@ class Radius extends Base implements IAuthConnector
             $radius = radius_auth_open();
 
             $error = null;
-            if (!radius_add_server(
-                $radius,
-                $this->radiusHost,
-                $this->acctPort,
-                $this->sharedSecret,
-                $this->timeout,
-                $this->maxRetries
-            )
+            if (
+                !radius_add_server(
+                    $radius,
+                    $this->radiusHost,
+                    $this->acctPort,
+                    $this->sharedSecret,
+                    $this->timeout,
+                    $this->maxRetries
+                )
             ) {
                 $error = radius_strerror($radius);
             } elseif (!radius_create_request($radius, RADIUS_ACCOUNTING_REQUEST)) {
@@ -211,14 +210,15 @@ class Radius extends Base implements IAuthConnector
             $radius = radius_auth_open();
 
             $error = null;
-            if (!radius_add_server(
-                $radius,
-                $this->radiusHost,
-                $this->acctPort,
-                $this->sharedSecret,
-                $this->timeout,
-                $this->maxRetries
-            )
+            if (
+                !radius_add_server(
+                    $radius,
+                    $this->radiusHost,
+                    $this->acctPort,
+                    $this->sharedSecret,
+                    $this->timeout,
+                    $this->maxRetries
+                )
             ) {
                 $error = radius_strerror($radius);
             } elseif (!radius_create_request($radius, RADIUS_ACCOUNTING_REQUEST)) {
@@ -291,14 +291,15 @@ class Radius extends Base implements IAuthConnector
             }
 
             $error = null;
-            if (!radius_add_server(
-                $radius,
-                $this->radiusHost,
-                $this->acctPort,
-                $this->sharedSecret,
-                $this->timeout,
-                $this->maxRetries
-            )
+            if (
+                !radius_add_server(
+                    $radius,
+                    $this->radiusHost,
+                    $this->acctPort,
+                    $this->sharedSecret,
+                    $this->timeout,
+                    $this->maxRetries
+                )
             ) {
                 $error = radius_strerror($radius);
             } elseif (!radius_create_request($radius, RADIUS_ACCOUNTING_REQUEST)) {
@@ -362,14 +363,16 @@ class Radius extends Base implements IAuthConnector
         $radius = radius_auth_open();
 
         $error = null;
-        if (!radius_add_server(
-            $radius,
-            $this->radiusHost,
-            $this->authPort,
-            $this->sharedSecret,
-            $this->timeout,
-            $this->maxRetries
-        )) {
+        if (
+            !radius_add_server(
+                $radius,
+                $this->radiusHost,
+                $this->authPort,
+                $this->sharedSecret,
+                $this->timeout,
+                $this->maxRetries
+            )
+        ) {
             $error = radius_strerror($radius);
         } elseif (!radius_create_request($radius, RADIUS_ACCESS_REQUEST)) {
             $error = radius_strerror($radius);
@@ -395,7 +398,7 @@ class Radius extends Base implements IAuthConnector
                     }
                     break;
                 default:
-                    syslog(LOG_ERR, 'Unsupported protocol '.$this->protocol);
+                    syslog(LOG_ERR, 'Unsupported protocol ' . $this->protocol);
                     return false;
             }
         }
@@ -416,19 +419,19 @@ class Radius extends Base implements IAuthConnector
                                     $this->lastAuthProperties['session_timeout'] = radius_cvt_int($resa['data']);
                                     break;
                                 case 85: // Acct-Interim-Interval
-                                    $this->lastAuthProperties['Acct-Interim-Interval'] =  radius_cvt_int($resa['data']);
+                                    $this->lastAuthProperties['Acct-Interim-Interval'] = radius_cvt_int($resa['data']);
                                     break;
                                 case RADIUS_FRAMED_IP_ADDRESS:
-                                    $this->lastAuthProperties['Framed-IP-Address'] =  radius_cvt_addr($resa['data']);
+                                    $this->lastAuthProperties['Framed-IP-Address'] = radius_cvt_addr($resa['data']);
                                     break;
                                 case RADIUS_FRAMED_IP_NETMASK:
-                                    $this->lastAuthProperties['Framed-IP-Netmask'] =  radius_cvt_addr($resa['data']);
+                                    $this->lastAuthProperties['Framed-IP-Netmask'] = radius_cvt_addr($resa['data']);
                                     break;
                                 case RADIUS_FRAMED_ROUTE:
                                     if (empty($this->lastAuthProperties['Framed-Route'])) {
                                         $this->lastAuthProperties['Framed-Route'] = array();
                                     }
-                                    $this->lastAuthProperties['Framed-Route'][] =  $resa['data'];
+                                    $this->lastAuthProperties['Framed-Route'][] = $resa['data'];
                                     break;
                                 default:
                                     break;
