@@ -31,9 +31,10 @@ namespace OPNsense\Base;
 use Exception;
 use OPNsense\Base\FieldTypes\ContainerField;
 use OPNsense\Core\Config;
+use Phalcon\Logger;
 use Phalcon\Logger\Adapter\Syslog;
 use Phalcon\Validation;
-use Phalcon\Validation\Message\Group;
+use Phalcon\Messages\Messages;
 use ReflectionClass;
 use ReflectionException;
 use SimpleXMLElement;
@@ -144,6 +145,8 @@ abstract class BaseModel
                     }
                     $check_derived = $check_derived->getParentClass();
                 }
+            } else {
+                throw new ModelException("class " . $classname . " missing");
             }
             if (!$is_derived_from_basefield) {
                 // class found, but of wrong type. raise an exception.
@@ -167,7 +170,7 @@ abstract class BaseModel
         // copy xml tag attributes to Field
         if ($config_data != null) {
             foreach ($config_data->attributes() as $AttrKey => $AttrValue) {
-                $internal_data->setAttributeValue($AttrKey, $AttrValue->__toString());
+                $internal_data->setAttributeValue($AttrKey, (string)$AttrValue);
             }
         }
 
@@ -223,7 +226,7 @@ abstract class BaseModel
                 }
                 if ($config_data != null && isset($config_data->$tagName)) {
                     // set field content from config (if available)
-                    $fieldObject->setValue($config_data->$tagName->__toString());
+                    $fieldObject->setValue((string)$config_data->$tagName);
                 }
             } else {
                 // add new child node container, always try to pass config data
@@ -246,7 +249,7 @@ abstract class BaseModel
                             $node_count++;
                             // Array items are identified by a UUID, read from attribute or create a new one
                             if (isset($conf_section->attributes()->uuid)) {
-                                $tagUUID = $conf_section->attributes()['uuid']->__toString();
+                                $tagUUID = (string)$conf_section->attributes()['uuid'];
                             } else {
                                 $tagUUID = $internal_data->generateUUID();
                             }
@@ -431,7 +434,7 @@ abstract class BaseModel
                     }
                 }
                 if (count($node_validators) > 0) {
-                    $validation_data[$key] = $node->__toString();
+                    $validation_data[$key] = (string)$node;
                 }
             }
         }
@@ -439,7 +442,7 @@ abstract class BaseModel
         if (count($validation_data) > 0) {
             $messages = $validation->validate($validation_data);
         } else {
-            $messages = new Group();
+            $messages = new Messages();
         }
 
         return $messages;
@@ -520,7 +523,7 @@ abstract class BaseModel
         // find parent of mountpoint (create if it doesn't exists)
         $target_node = $config_xml;
         $str_parts = explode("/", str_replace("//", "/", $this->internal_mountpoint));
-        for ($i = 0; $i < count($str_parts) - 1; $i++) {
+        for ($i = 0; $i < count($str_parts); $i++) {
             if ($str_parts[$i] != "") {
                 if (count($target_node->xpath($str_parts[$i])) == 0) {
                     $target_node = $target_node->addChild($str_parts[$i]);
@@ -533,14 +536,8 @@ abstract class BaseModel
         // copy model data into config
         $toDom = dom_import_simplexml($target_node);
         $fromDom = dom_import_simplexml($source_node[0]);
-
-        // remove old model data and write new
-        foreach ($toDom->childNodes as $childNode) {
-            if ($childNode->nodeName == $fromDom->nodeName) {
-                $toDom->removeChild($childNode);
-            }
-        }
-        $toDom->appendChild($toDom->ownerDocument->importNode($fromDom, true));
+        $nodeImport  = $toDom->ownerDocument->importNode($fromDom, true);
+        $toDom->parentNode->replaceChild($nodeImport, $toDom);
     }
 
     /**
@@ -553,10 +550,12 @@ abstract class BaseModel
     public function serializeToConfig($validateFullModel = false, $disable_validation = false)
     {
         // create logger to save possible consistency issues to
-        $logger = new Syslog("config", array(
-            'option' => LOG_PID,
-            'facility' => LOG_LOCAL2
-        ));
+        $logger = new Logger(
+            'messages',
+            [
+                'main' => new Syslog("config", ['option' => LOG_PID, 'facility' => LOG_LOCAL2])
+            ]
+        );
 
         // Perform validation, collect all messages and raise exception if validation is not disabled.
         // If for some reason the developer chooses to ignore the errors, let's at least log there something
@@ -632,7 +631,12 @@ abstract class BaseModel
         if (version_compare($this->internal_current_model_version, $this->internal_model_version, '<')) {
             $upgradePerfomed = false;
             $migObjects = array();
-            $logger = new Syslog("config", array('option' => LOG_PID, 'facility' => LOG_LOCAL2));
+            $logger = new Logger(
+                'messages',
+                [
+                    'main' => new Syslog("config", ['option' => LOG_PID, 'facility' => LOG_LOCAL2])
+                ]
+            );
             $class_info = new ReflectionClass($this);
             // fetch version migrations
             $versions = array();
