@@ -35,6 +35,7 @@ import sys
 import ujson
 import requests
 import zipfile
+import syslog
 from configparser import ConfigParser
 
 
@@ -56,10 +57,14 @@ def download_geolite():
         'locations_filename': None,
         'address_sources': {'IPv4': None, 'IPv6': None}
     }
-    if url is not None:
+    if url is not None and url.lower().startswith('http'):
         # flush data from remote url to temp file and unpack from there
         with tempfile.NamedTemporaryFile() as tmp_stream:
-            r = requests.get(url)
+            try:
+                r = requests.get(url)
+            except Exception as e:
+                syslog.syslog(syslog.LOG_ERR, 'geoip update failed : %s' % e)
+                return result
             if r.status_code == 200:
                 tmp_stream.write(r.content)
                 tmp_stream.seek(0)
