@@ -82,11 +82,11 @@ if (isset($nginx['http_server'])) {
         $http_servers = array($nginx['http_server']);
     }
     foreach ($http_servers as $http_server) {
-        if (!empty($http_server['listen_https_port']) && !empty($http_server['certificate'])) {
+        if (!empty($http_server['listen_https_address']) && !empty($http_server['certificate'])) {
           // try to find the reference
             $cert = find_cert($http_server['certificate']);
             if (!isset($cert)) {
-                next;
+                continue;
             }
             $chain = [];
             $ca_chain = ca_chain_array($cert);
@@ -121,17 +121,17 @@ if (isset($nginx['http_server'])) {
 }
 // end http, begin streams
 if (isset($nginx['stream_server'])) {
-    if (is_array($nginx['stream_server']) && !isset($nginx['stream_server']['servername'])) {
+    if (is_array($nginx['stream_server']) && !isset($nginx['stream_server']['@attributes']['uuid'])) {
         $stream_servers = $nginx['stream_server'];
     } else {
         $stream_servers = array($nginx['stream_server']);
     }
     foreach ($stream_servers as $stream_server) {
-        if (!empty($stream_server['listen_port']) && !empty($stream_server['certificate'])) {
+        if (!empty($stream_server['listen_address']) && !empty($stream_server['certificate'])) {
           // try to find the reference
             $cert = find_cert($stream_server['certificate']);
             if (!isset($cert)) {
-                next;
+                continue;
             }
             $chain = [];
             $ca_chain = ca_chain_array($cert);
@@ -154,7 +154,7 @@ if (isset($nginx['stream_server'])) {
                     $ca = find_ca($caref);
                     if (isset($ca)) {
                         export_pem_file(
-                            KEY_DIRECTORY . $hostname . '_ca.pem',
+                            KEY_DIRECTORY . $stream_server['@attributes']['uuid'] . '_ca.pem',
                             $ca['crt']
                         );
                     }
@@ -184,7 +184,7 @@ if (isset($nginx['upstream'])) {
                     foreach (ca_chain_array($cert) as $entry) {
                         $chain[] = base64_decode($entry['crt']);
                     }
-                    $hostname = explode(',', $http_server['servername'])[0];
+
                     export_pem_file(
                         KEY_DIRECTORY . $upstream['tls_client_certificate'] . '.pem',
                         $cert['crt'],
@@ -198,16 +198,16 @@ if (isset($nginx['upstream'])) {
             }
             if (!empty($upstream['tls_trusted_certificate'])) {
                 $cas = array();
-                if (is_array($http_server['ca'])) {
-                    foreach ($http_server['ca'] as $caref) {
-                        $ca = find_ca($caref);
-                        if (isset($ca)) {
-                            $cas[] = $ca;
-                        }
+                $carefs = explode(",", $upstream['tls_trusted_certificate']);
+                foreach ($carefs as $caref) {
+                    $ca = find_ca($caref);
+                    if (isset($ca)) {
+                        $cas[] = base64_decode($ca['crt']);
                     }
                 }
                 export_pem_file(
                     '/usr/local/etc/nginx/key/trust_upstream_' . $upstream_uuid . '.pem',
+                    '',
                     implode("\n", $cas)
                 );
             }
@@ -239,11 +239,65 @@ foreach ($nginx->userlist->iterateItems() as $user_list) {
         unset($file);
     }
 }
+
 // create directories for cache
 foreach ($nginx->cache_path->iterateItems() as $cache_path) {
     @mkdir((string)$cache_path->path, 0755, true);
 }
 
+// create custom error pages
+const ERRORPAGE_DIR = '/usr/local/etc/nginx/views';
+@mkdir(ERRORPAGE_DIR, 0755, true);
+$used_errorpages = array();
+// search used error pages in http servers and locations
+foreach (array($nginx->http_server, $nginx->location) as $entity) {
+    foreach ($entity->iterateItems() as $element) {
+        $pages = explode(',', $element->errorpages);
+        foreach ($pages as $page) {
+            $page = str_replace('-', '', $page);
+            if (!in_array($page, $used_errorpages)) {
+                $used_errorpages[] = $page;
+            }
+        }
+    }
+}
+// search used WAF error pages
+foreach ($nginx->location->iterateItems() as $location) {
+    if ($location->secrules_errorpage != '') {
+        $page = str_replace('-', '', $location->secrules_errorpage);
+        if (!in_array($page, $used_errorpages)) {
+            $used_errorpages[] = $page;
+        }
+    }
+}
+// create/update error pages
+foreach ($nginx->errorpage->iterateItems() as $errorpage) {
+    $uuid = str_replace('-', '', $errorpage->getAttributes()['uuid']);
+    if (in_array($uuid, $used_errorpages)) {
+        $filename = "error_$uuid.html";
+        $content = base64_decode((string)$errorpage->pagecontent);
+        // Does error page have a content?
+        if (strlen($content) > 0) {
+            $fs_hash = @hash_file("sha1", ERRORPAGE_DIR . "/$filename");
+            if ($fs_hash !== hash("sha1", $content)) {
+                @file_put_contents(ERRORPAGE_DIR . "/$filename", $content);
+            }
+            chmod(ERRORPAGE_DIR . "/$filename", 0644);
+        } else {
+            unset($used_errorpages[array_search($uuid, $used_errorpages)]);
+        }
+    }
+}
+// delete unused (old) error pages
+$dir = new \DirectoryIterator(ERRORPAGE_DIR);
+foreach ($dir as $file) {
+    if ($file->isFile() && strpos($file->getFilename(), 'error_') === 0) {
+        if (!in_array(substr($file->getFilename(), 6, 32), $used_errorpages)) {
+            @unlink($file->getPathname());
+        }
+    }
+}
+
 // export TLS fingerprint database for MitM detection
 $tls_fingerprint_database = array();
 foreach ($nginx->tls_fingerprint->iterateItems() as $tls_fingerprint) {
