@@ -58,7 +58,7 @@ def exec_config_cmd(exec_command):
         sock.connect(configd_socket_name)
     except socket.error:
         syslog_error('unable to connect to configd socket (@%s)'%configd_socket_name)
-        print('unable to connect to configd socket (@%s)'%configd_socket_name)
+        print('unable to connect to configd socket (@%s)'%configd_socket_name, file=sys.stderr)
         return None
 
     try:
@@ -73,8 +73,8 @@ def exec_config_cmd(exec_command):
 
         return ''.join(data)[:-3]
     except:
-        print ('error in configd communication %s, see syslog for details')
         syslog_error('error in configd communication \n%s'%traceback.format_exc())
+        print ('error in configd communication %s, see syslog for details', file=sys.stderr)
     finally:
         sock.close()
 
@@ -82,6 +82,8 @@ def exec_config_cmd(exec_command):
 parser = argparse.ArgumentParser()
 parser.add_argument("-m", help="execute multiple arguments at once", action="store_true")
 parser.add_argument("-e", help="use as event handler, execute command on receiving input", action="store_true")
+parser.add_argument("-d", help="detach the execution of the command and return immediately", action="store_true")
+parser.add_argument("-q", help="run quietly by muting standard output", action="store_true")
 parser.add_argument(
     "-t",
     help="threshold between events,  wait this interval before executing commands, combine input into single events",
@@ -105,7 +107,7 @@ while not os.path.exists(configd_socket_name):
     i += 1
 
 if not os.path.exists(configd_socket_name):
-    print('configd socket missing (@%s)'%configd_socket_name)
+    print('configd socket missing (@%s)'%configd_socket_name, file=sys.stderr)
     sys.exit(-1)
 
 
@@ -125,7 +127,11 @@ if args.e:
         rlist, _, _ = select([sys.stdin], [], [], args.t)
         if rlist:
             last_message_stamp = time.time()
-            stashed_lines.append(sys.stdin.readline())
+            r_line = sys.stdin.readline()
+            if len(r_line) == 0:
+                #EOFError. pipe broken?
+                sys.exit(-1)
+            stashed_lines.append(r_line)
 
         if len(stashed_lines) >= 1 and (args.t is None or time.time() - last_message_stamp > args.t):
             # emit event trigger(s) to syslog
@@ -139,7 +145,10 @@ if args.e:
 else:
     # normal execution mode
     for exec_command in exec_commands:
+        if args.d:
+            exec_command = '&' + exec_command
         result=exec_config_cmd(exec_command=exec_command)
         if result is None:
             sys.exit(-1)
-        print('%s' % (result.strip()))
+        if not args.q:
+            print('%s' % (result.strip()))
