@@ -1,33 +1,29 @@
-/**
- *    Copyright (C) 2015-2019 Deciso B.V.
+/*
+ * Copyright (C) 2015-2021 Deciso B.V.
+ * All rights reserved.
  *
- *    All rights reserved.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
  *
- *    Redistribution and use in source and binary forms, with or without
- *    modification, are permitted provided that the following conditions are met:
+ * 1. Redistributions of source code must retain the above copyright notice,
+ *    this list of conditions and the following disclaimer.
  *
- *    1. Redistributions of source code must retain the above copyright notice,
- *       this list of conditions and the following disclaimer.
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
  *
- *    2. Redistributions in binary form must reproduce the above copyright
- *       notice, this list of conditions and the following disclaimer in the
- *       documentation and/or other materials provided with the distribution.
- *
- *    THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES,
- *    INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
- *    AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
- *    AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
- *    OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
- *    SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
- *    INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
- *    CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
- *    ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
- *    POSSIBILITY OF SUCH DAMAGE.
- *
- * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES,
+ * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
+ * AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
+ * AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
+ * OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+ * POSSIBILITY OF SUCH DAMAGE.
  */
 
-
 /**
  * reload bootgrid, return to current selected page
  */
@@ -113,31 +109,32 @@ $.fn.UIBootgrid = function (params) {
             useRequestHandlerOnGet: false,
             formatters: {
                 "commands": function (column, row) {
-                    return "<button type=\"button\" class=\"btn btn-xs btn-default command-edit\" data-row-id=\"" + row.uuid + "\"><span class=\"fa fa-pencil\"></span></button> " +
-                        "<button type=\"button\" class=\"btn btn-xs btn-default command-copy\" data-row-id=\"" + row.uuid + "\"><span class=\"fa fa-clone\"></span></button>" +
-                        "<button type=\"button\" class=\"btn btn-xs btn-default command-delete\" data-row-id=\"" + row.uuid + "\"><span class=\"fa fa-trash-o\"></span></button>";
+                    return '<button type="button" class="btn btn-xs btn-default command-edit bootgrid-tooltip" data-row-id="' + row.uuid + '"><span class="fa fa-fw fa-pencil"></span></button> ' +
+                        '<button type="button" class="btn btn-xs btn-default command-copy bootgrid-tooltip" data-row-id="' + row.uuid + '"><span class="fa fa-fw fa-clone"></span></button>' +
+                        '<button type="button" class="btn btn-xs btn-default command-delete bootgrid-tooltip" data-row-id="' + row.uuid + '"><span class="fa fa-fw fa-trash-o"></span></button>';
                 },
                 "commandsWithInfo": function(column, row) {
-                    return "<button type=\"button\" class=\"btn btn-xs btn-default command-info\" data-row-id=\"" + row.uuid + "\"><span class=\"fa fa-info-circle\"></span></button> " +
-                        "<button type=\"button\" class=\"btn btn-xs btn-default command-edit\" data-row-id=\"" + row.uuid + "\"><span class=\"fa fa-pencil\"></span></button>" +
-                        "<button type=\"button\" class=\"btn btn-xs btn-default command-copy\" data-row-id=\"" + row.uuid + "\"><span class=\"fa fa-clone\"></span></button>" +
-                        "<button type=\"button\" class=\"btn btn-xs btn-default command-delete\" data-row-id=\"" + row.uuid + "\"><span class=\"fa fa-trash-o\"></span></button>";
+                    return '<button type="button" class="btn btn-xs btn-default command-info bootgrid-tooltip" data-row-id="' + row.uuid + '"><span class="fa fa-fw fa-info-circle"></span></button> ' +
+                        '<button type="button" class="btn btn-xs btn-default command-edit bootgrid-tooltip" data-row-id="' + row.uuid + '"><span class="fa fa-fw fa-pencil"></span></button>' +
+                        '<button type="button" class="btn btn-xs btn-default command-copy bootgrid-tooltip" data-row-id="' + row.uuid + '"><span class="fa fa-fw fa-clone"></span></button>' +
+                        '<button type="button" class="btn btn-xs btn-default command-delete bootgrid-tooltip" data-row-id="' + row.uuid + '"><span class="fa fa-fw fa-trash-o"></span></button>';
                 },
                 "rowtoggle": function (column, row) {
                     if (parseInt(row[column.id], 2) === 1) {
-                        return "<span style=\"cursor: pointer;\" class=\"fa fa-check-square-o command-toggle\" data-value=\"1\" data-row-id=\"" + row.uuid + "\"></span>";
+                        return '<span style="cursor: pointer;" class="fa fa-fw fa-check-square-o command-toggle bootgrid-tooltip" data-value="1" data-row-id="' + row.uuid + '"></span>';
                     } else {
-                        return "<span style=\"cursor: pointer;\" class=\"fa fa-square-o command-toggle\" data-value=\"0\" data-row-id=\"" + row.uuid + "\"></span>";
+                        return '<span style="cursor: pointer;" class="fa fa-fw fa-square-o command-toggle bootgrid-tooltip" data-value="0" data-row-id="' + row.uuid + '"></span>';
                     }
                 },
                 "boolean": function (column, row) {
                     if (parseInt(row[column.id], 2) === 1) {
-                        return "<span class=\"fa fa-check\" data-value=\"1\" data-row-id=\"" + row.uuid + "\"></span>";
+                        return "<span class=\"fa fa-fw fa-check\" data-value=\"1\" data-row-id=\"" + row.uuid + "\"></span>";
                     } else {
-                        return "<span class=\"fa fa-times\" data-value=\"0\" data-row-id=\"" + row.uuid + "\"></span>";
+                        return "<span class=\"fa fa-fw fa-times\" data-value=\"0\" data-row-id=\"" + row.uuid + "\"></span>";
                     }
                 },
-            }
+            },
+            onBeforeRenderDialog: null
         };
 
         // merge additional options (if any)
@@ -152,21 +149,7 @@ $.fn.UIBootgrid = function (params) {
         } else {
             this_grid.requestHandler = null;
         }
-
-        if ($(this_grid).data('store-selection') === true && window.localStorage) {
-            // fetch last selected rowcount, sort on top so it will be the current active selection
-            let grid_id = window.location.pathname + '#' + this_grid.attr('id');
-            let count = parseInt(window.localStorage.getItem(grid_id+"_items")) ;
-            if (count !== null) {
-                if (Array.isArray(gridopt.rowCount)) {
-                    let index = gridopt.rowCount.indexOf(count);
-                    if (index > -1) {
-                        gridopt.rowCount.splice(index, 1);
-                        gridopt.rowCount.unshift(count);
-                    }
-                }
-            }
-        }
+        this_grid.onBeforeRenderDialog = gridopt.onBeforeRenderDialog;
 
         // construct a new grid
         return this_grid.bootgrid(gridopt).on("loaded.rs.jquery.bootgrid", function (e) {
@@ -188,37 +171,53 @@ $.fn.UIBootgrid = function (params) {
         });
     };
 
+    this.show_edit_dialog = function(event, endpoint) {
+        const dfObj = new $.Deferred();
+        let editDlg = this_grid.attr('data-editDialog');
+        let urlMap = {};
+        let server_params = undefined;
+
+        urlMap['frm_' + editDlg] = endpoint;
+        if (this_grid.requestHandler !== null) {
+            // our requestHandler returns a JSON object, convert it back first
+            server_params = this_grid.requestHandler({});
+        }
+        mapDataToFormUI(urlMap, server_params).done(function(payload){
+            // update selectors
+            formatTokenizersUI();
+            $('.selectpicker').selectpicker('refresh');
+            // clear validation errors (if any)
+            clearFormValidation('frm_' + editDlg);
+            // show dialog
+            $('#'+editDlg).modal({backdrop: 'static', keyboard: false});
+            if (this_grid.onBeforeRenderDialog) {
+                this_grid.onBeforeRenderDialog(payload).done(function(){
+                    dfObj.resolve();
+                });
+            } else {
+                dfObj.resolve();
+            }
+        });
+        return dfObj;
+    };
+
     /**
      * add event
      */
     this.command_add = function(event) {
+        event.stopPropagation();
         let editDlg = this_grid.attr('data-editDialog');
         if (editDlg !== undefined) {
-            let urlMap = {};
-            let server_params = undefined;
-            urlMap['frm_' + editDlg] = params['get'];
-            if (this_grid.requestHandler !== null) {
-                // our requestHandler returns a JSON object, convert it back first
-                server_params = this_grid.requestHandler({});
-            }
-            mapDataToFormUI(urlMap, server_params).done(function(){
-                // update selectors
-                formatTokenizersUI();
-                $('.selectpicker').selectpicker('refresh');
-                // clear validation errors (if any)
-                clearFormValidation('frm_' + editDlg);
+            let saveDlg = $("#btn_"+editDlg+"_save").unbind('click');
+            this_grid.show_edit_dialog(event, params['get']).done(function(){
                 $('#'+editDlg).trigger('opnsense_bootgrid_mapped', ['add']);
-            });
-
-            // show dialog for edit
-            $('#'+editDlg).modal({backdrop: 'static', keyboard: false});
-            //
-            $("#btn_"+editDlg+"_save").unbind('click').click(function(){
-                saveFormToEndpoint(params['add'], 'frm_' + editDlg, function(){
-                        $("#"+editDlg).modal('hide');
-                        std_bootgrid_reload(this_grid.attr('id'));
-                        this_grid.showSaveAlert(event);
-                    }, true);
+                saveDlg.click(function(){
+                    saveFormToEndpoint(params['add'], 'frm_' + editDlg, function(){
+                            $("#"+editDlg).modal('hide');
+                            std_bootgrid_reload(this_grid.attr('id'));
+                            this_grid.showSaveAlert(event);
+                        }, true);
+                });
             });
         } else {
             console.log("[grid] action get or data-editDialog missing")
@@ -243,22 +242,13 @@ $.fn.UIBootgrid = function (params) {
      * edit event
      */
     this.command_edit = function(event) {
+        event.stopPropagation();
         let editDlg = this_grid.attr('data-editDialog');
         if (editDlg !== undefined) {
             let uuid = $(this).data("row-id");
-            let urlMap = {};
-            urlMap['frm_' + editDlg] = params['get'] + uuid;
-            mapDataToFormUI(urlMap).done(function () {
-                // update selectors
-                formatTokenizersUI();
-                $('.selectpicker').selectpicker('refresh');
-                // clear validation errors (if any)
-                clearFormValidation('frm_' + editDlg);
-
-                // show dialog for pipe edit
-                $('#'+editDlg).modal({backdrop: 'static', keyboard: false});
-                // define save action
-                $("#btn_"+editDlg+"_save").unbind('click').click(function(){
+            let saveDlg = $("#btn_"+editDlg+"_save").unbind('click');
+            this_grid.show_edit_dialog(event, params['get'] + uuid).done(function(){
+                saveDlg.unbind('click').click(function(){
                     saveFormToEndpoint(params['set']+uuid, 'frm_' + editDlg, function(){
                             $("#"+editDlg).modal('hide');
                             std_bootgrid_reload(this_grid.attr('id'));
@@ -276,9 +266,9 @@ $.fn.UIBootgrid = function (params) {
      * delete event
      */
     this.command_delete = function(event) {
+        event.stopPropagation();
         let uuid=$(this).data("row-id");
-        // XXX must be replaced, cannot translate
-        stdDialogRemoveItem('Remove selected item?',function() {
+        stdDialogRemoveItem($.fn.UIBootgrid.defaults.removeWarningText,function() {
             ajaxCall(params['del'] + uuid, {},function(data,status){
                 // reload grid after delete
                 std_bootgrid_reload(this_grid.attr('id'));
@@ -290,8 +280,8 @@ $.fn.UIBootgrid = function (params) {
      * delete selected event
      */
     this.command_delete_selected = function(event) {
-        // XXX must be replaced, cannot translate
-        stdDialogRemoveItem("Remove selected items?",function(){
+        event.stopPropagation();
+        stdDialogRemoveItem($.fn.UIBootgrid.defaults.removeWarningText,function(){
             const rows = $("#" + this_grid.attr('id')).bootgrid('getSelectedRows');
             if (rows !== undefined){
                 const deferreds = [];
@@ -310,11 +300,12 @@ $.fn.UIBootgrid = function (params) {
      * copy event
      */
     this.command_copy = function(event) {
+        event.stopPropagation();
         const editDlg = this_grid.attr('data-editDialog');
         if (editDlg !== undefined) {
             const uuid = $(this).data("row-id");
             const urlMap = {};
-            urlMap['frm_' + editDlg] = params['get'] + uuid;
+            urlMap['frm_' + editDlg] = params['get'] + uuid + "?fetchmode=copy";
             mapDataToFormUI(urlMap).done(function () {
                 // update selectors
                 formatTokenizersUI();
@@ -343,6 +334,7 @@ $.fn.UIBootgrid = function (params) {
      * info event
      */
     this.command_info = function(event) {
+        event.stopPropagation();
         const uuid = $(this).data("row-id");
         ajaxGet(params['info'] + uuid, {}, function(data, status) {
             if(status === 'success') {
@@ -358,6 +350,7 @@ $.fn.UIBootgrid = function (params) {
      * toggle event
      */
     this.command_toggle = function(event) {
+        event.stopPropagation();
         const uuid = $(this).data("row-id");
         $(this).addClass("fa-spinner fa-pulse");
         ajaxCall(params['toggle'] + uuid, {},function(data,status){
@@ -366,65 +359,16 @@ $.fn.UIBootgrid = function (params) {
         });
     };
 
-    /**
-     * load previous selections
-     */
-    this.load_selection = function() {
-        if ($(this_grid).data('store-selection') === true && window.localStorage) {
-            const grid_id = window.location.pathname + '#' + this_grid.attr('id');
-            try {
-                const settings = JSON.parse(window.localStorage.getItem(grid_id));
-                if (settings != null) {
-                    $.each(settings, function(field, value){
-                        $('#'+ this_grid.attr('id')).find('[data-column-id="' +field+ '"]').data('visible', value);
-                    });
-                }
-            } catch (e) {
-            }
-        }
-    };
-
-    /**
-     * store selections when data-store-selection=true
-     */
-    this.store_selection = function() {
-        if ($(this_grid).data('store-selection') === true && window.localStorage) {
-            const grid_id = window.location.pathname + '#' + this_grid.attr('id');
-            // hook event handler to catch changing column selections
-            $("#"+this_grid.attr('id')+"-header .dropdown-item-checkbox").unbind('click').click(function () {
-                let settings = {};
-                try {
-                    settings = JSON.parse(window.localStorage.getItem(grid_id));
-                    if (settings == null) {
-                        settings = {};
-                    }
-                } catch (e) {
-                    settings = {};
-                }
-                if ($(this).attr('name') !== undefined) {
-                    settings[$(this).attr('name')] = $(this).is(':checked');
-                }
-                window.localStorage.setItem(grid_id, JSON.stringify(settings));
-            });
-            // hook event handler to catch changing row counters
-            $("#"+this_grid.attr('id')+"-header .dropdown-item-button").unbind('click').click(function () {
-                window.localStorage.setItem(grid_id+"_items", $(this).data('action'));
-            });
-        }
-    };
-
     /**
      * init bootgrids
      */
     return this.each((function(){
         // since we start using simple class selectors for our commands, we need to make sure "add" and
         // "delete selected" actions are properly marked
-        $(this).find("*[data-action=add]").addClass('command-add');
-        $(this).find("*[data-action=deleteSelected]").addClass('command-delete-selected');
+        $(this).find("*[data-action=add]").addClass('command-add bootgrid-tooltip');
+        $(this).find("*[data-action=deleteSelected]").addClass('command-delete-selected bootgrid-tooltip');
 
         if (params !== undefined && params['search'] !== undefined) {
-            // load previous selections when enabled
-            this_grid.load_selection();
             // create new bootgrid component and link source
             const grid = this_grid.construct();
 
@@ -433,6 +377,34 @@ $.fn.UIBootgrid = function (params) {
 
             // link edit and delete event buttons
             grid.on("loaded.rs.jquery.bootgrid", function(){
+                // toggle all automated tooltips
+                $(this).find(".bootgrid-tooltip").each(function (index) {
+                    if ($(this).attr('title') !== undefined) {
+                        // keep this tooltip
+                    } else if ($(this).hasClass('command-add')) {
+                        $(this).attr('title', $.fn.UIBootgrid.defaults.addText);
+                    } else if ($(this).hasClass('command-delete-selected')) {
+                        $(this).attr('title', $.fn.UIBootgrid.defaults.deleteSelectedText);
+                    } else if ($(this).hasClass('command-edit')) {
+                        $(this).attr('title', $.fn.UIBootgrid.defaults.editText);
+                    } else if ($(this).hasClass('command-toggle')) {
+                        if ($(this).data('value') == 1) {
+                            $(this).attr('title', $.fn.UIBootgrid.defaults.disableText);
+                        } else {
+                            $(this).attr('title', $.fn.UIBootgrid.defaults.enableText);
+                        }
+                    } else if ($(this).hasClass('command-delete')) {
+                        $(this).attr('title', $.fn.UIBootgrid.defaults.deleteText);
+                    } else if ($(this).hasClass('command-info')) {
+                        $(this).attr('title', $.fn.UIBootgrid.defaults.infoText);
+                    } else if ($(this).hasClass('command-copy')) {
+                        $(this).attr('title', $.fn.UIBootgrid.defaults.cloneText);
+                    } else {
+                        $(this).attr('title', 'Error: no tooltip match');
+                    }
+                    $(this).tooltip();
+                });
+
                 // hook all events
                 const commands = this_grid.getCommands();
                 Object.keys(commands).map(function (k) {
@@ -448,10 +420,11 @@ $.fn.UIBootgrid = function (params) {
                         console.log("not all requirements met to link " + k);
                     }
                 });
-                // store selections when enabled
-                this_grid.store_selection();
             });
+
             return grid;
         }
     }));
 };
+
+$.fn.UIBootgrid.defaults = { /* translations are rendered in the default page template */ };
