@@ -181,7 +181,7 @@ function updateServiceControlUI(serviceName)
         if (data['status'] === "running") {
             status_html += 'label-success';
             status_icon = 'play';
-            buttons += '<span id="restartService" class="btn btn-sm btn-default"><i class="fa fa-refresh fa-fw"></i></span> ';
+            buttons += '<span id="restartService" class="btn btn-sm btn-default"><i class="fa fa-repeat fa-fw"></i></span>';
             buttons += '<span id="stopService" class="btn btn-sm btn-default"><i class="fa fa-stop fa-fw"></span>';
         } else if (data['status'] === "stopped") {
             status_html += 'label-danger';
@@ -296,6 +296,10 @@ function formatTokenizersUI() {
  * clear multiselect boxes on click event, works on standard and tokenized versions
  */
 function addMultiSelectClearUI() {
+    //enable Paste if supported
+    if ((typeof navigator.clipboard === 'object') && (typeof navigator.clipboard.readText === 'function')) {
+        $('.fa-paste').parent().show();
+    }
     $('[id*="clear-options"]').each(function() {
         $(this).click(function() {
             const id = $(this).attr("id").replace(/_*clear-options_*/, '');
@@ -334,6 +338,37 @@ function addMultiSelectClearUI() {
             });
         });
     });
+    $('[id*="copy-options"]').each(function() {
+        $(this).click(function(e) {
+            e.preventDefault();
+            var currentFocus = document.activeElement;
+            let src_id = $(this).attr("id").replace(/_*copy-options_*/, '');
+            let element = $('select[id="' + src_id + '"]');
+            let target = $("<textarea style='opacity:0;'/>").val(element.val().join('\n')) ;
+            element.after(target);
+            target.select().focus();
+            document.execCommand("copy");
+            target.remove();
+            if (currentFocus && typeof currentFocus.focus === "function") {
+                currentFocus.focus();
+            }
+        });
+    });
+    $('[id*="paste-options"]').each(function() {
+        $(this).click(function(e) {
+            e.preventDefault();
+            let id = $(this).attr("id").replace(/_*paste-options_*/, '');
+            let target = $('select[id="' + id + '"]');
+            var cpb = navigator.clipboard.readText();
+            $.when(cpb).then(function(cbtext) {
+                let values = $.trim(cbtext).replace(/\n|\r/g, ",").split(",");
+                $.each(values, function( index, value ) {
+                     target.tokenize2().trigger('tokenize:tokens:add', [value, value, true]);
+                });
+                target.change(); // signal subscribers about changed data
+            });
+        });
+    });
 }
 
 
@@ -377,16 +412,39 @@ function initFormHelpUI() {
  * handle advanced show/hide
  */
 function initFormAdvancedUI() {
+
+    // handle striped tables hidden rows
+    let targetNodes = $('table.table-striped tbody');
+    let config = { attributes: true, subtree: true, attributeFilter: ["style"] };
+    let callback = function(mutationsList, observer) {
+        mutationsList.forEach(function(mutation) {
+            if (mutation.target.tagName == "TR") {
+                let currentValue = mutation.target.style.display;
+                if (currentValue == "") {
+                    // row is visible
+                    $(mutation.target).next('.dummy_row').remove();
+                } else if (currentValue == "none" && !$(mutation.target).next().hasClass("dummy_row")) {
+                    // row is hidden and no dummy rows after it. insert one to keep stripes order
+                    $(mutation.target).after("<tr data-advanced='hidden_row' class='dummy_row'></tr>");
+                }
+            }
+        });
+    }
+
+    observer = new MutationObserver(callback);
+    // observe all striped tables on page for style changes
+    targetNodes.each(function(index, node) {
+        observer.observe(node, config);
+    });
+
+    //  handle "advanced mode" toggle
     let elements = $('[id*="show_advanced"]');
     if (window.sessionStorage && sessionStorage.getItem('show_advanced_preset') === 1) {
         // show advanced options when preset was stored
         elements.toggleClass("fa-toggle-on fa-toggle-off");
         elements.toggleClass("text-success text-danger");
     } else {
-        $('[data-advanced*="true"]').hide(function(){
-            // the table row is added to keep correct table striping
-            $(this).after("<tr data-advanced='hidden_row'></tr>");
-        });
+        $('[data-advanced*="true"]').hide();
     }
 
     elements.click(function() {
@@ -394,12 +452,11 @@ function initFormAdvancedUI() {
         elements.toggleClass("text-success text-danger");
         if (elements.hasClass("fa-toggle-on")) {
             $('[data-advanced*="true"]').show();
-            $('[data-advanced*="hidden_row"]').remove(); // the table row is deleted to keep correct table striping
             if (window.sessionStorage) {
                 sessionStorage.setItem('show_advanced_preset', 1);
             }
         } else {
-            $('[data-advanced*="true"]').after("<tr data-advanced='hidden_row'></tr>").hide(); // the table row is added to keep correct table striping
+            $('[data-advanced*="true"]').hide()
             if (window.sessionStorage) {
                 sessionStorage.setItem('show_advanced_preset', 0);
             }
