@@ -1,13 +1,16 @@
 --
--- (C) 2018 - ntop.org
+-- (C) 2021 - ntop.org
 --
--- This file contains the alert constats
+-- This file contains the alert constants
 
 local dirs = ntop.getDirs()
+package.path = dirs.installdir .. "/scripts/lua/modules/alert_keys/?.lua;" .. package.path
 package.path = dirs.installdir .. "/scripts/lua/modules/pools/?.lua;" .. package.path
 
+local alert_severities = require "alert_severities"
+local alert_entities = require "alert_entities"
 local alert_consts = {}
-local alert_keys = require "alert_keys"
+local alert = require "alert" -- The alert base class
 local format_utils  = require "format_utils"
 local os_utils = require("os_utils")
 local plugins_utils = require("plugins_utils")
@@ -24,88 +27,6 @@ alert_consts.MAX_NUM_QUEUED_ALERTS_PER_MODULE = 1024 -- should match ALERTS_MANA
 
 alert_consts.MAX_NUM_QUEUED_ALERTS_PER_RECIPIENT = 4096
 
--- Emoji Unicode Icons
--- https://apps.timwhitlock.info/emoji/tables/unicode
--- https://www.unicode.org/emoji/charts/full-emoji-list.html
-
--- Alerts (Keep severity_id in sync with ntop_typedefs.h AlertLevel)
--- each table entry is an array as:
--- {"alert html string", "alert C enum value", "plain string", "syslog severity"}
-alert_consts.alert_severities = {
-   debug = {
-      severity_id = 1,
-      label = "badge-info",
-      icon = "fas fa-bug text-info",
-      -- color = "black",
-      i18n_title = "alerts_dashboard.debug",
-      syslog_severity = 7,
-      emoji = "\xE2\x84\xB9"
-   },
-   info = {
-      severity_id = 2,
-      label = "badge-info",
-      icon = "fas fa-info-circle text-info",
-      -- color = "blue",
-      i18n_title = "alerts_dashboard.info",
-      syslog_severity = 6,
-      emoji = "\xE2\x84\xB9"
-   },
-   notice = {
-      severity_id = 3,
-      label = "badge-info",
-      icon = "fas fa-hand-paper text-primary",
-      -- color = "blue",
-      i18n_title = "alerts_dashboard.notice",
-      syslog_severity = 5,
-      emoji = "\xE2\x84\xB9"
-   },
-   warning = {
-      severity_id = 4,
-      label = "badge-warning",
-      icon = "fas fa-exclamation-triangle text-warning",
-      -- color = "gold",
-      i18n_title = "alerts_dashboard.warning",
-      syslog_severity = 4,
-      emoji = "\xE2\x9A\xA0"
-   },
-   error = {
-      severity_id = 5,
-      label = "badge-danger",
-      icon = "fas fa-exclamation-triangle text-danger",
-      -- color = "red",
-      i18n_title = "alerts_dashboard.error",
-      syslog_severity = 3,
-      emoji = "\xE2\x9D\x97"
-   },
-   critical = {
-      severity_id = 6,
-      label = "badge-danger",
-      icon = "fas fa-exclamation-triangle text-danger",
-      -- color = "purple",
-      i18n_title = "alerts_dashboard.critical",
-      syslog_severity = 2,
-      emoji = "\xE2\x9D\x97"
-   },
-   alert = {
-      severity_id = 7,
-      label = "badge-danger",
-      icon = "fas fa-bomb text-danger",
-      -- color = "red",
-      i18n_title = "alerts_dashboard.alert",
-      syslog_severity = 1,
-      emoji = "\xF0\x9F\x9A\xA9"
-   },
-   emergency = {
-      severity_id = 8,
-      label = "badge-danger text-danger",
-      icon = "fas fa-bomb",
-      -- color = "purple",
-      i18n_title = "alerts_dashboard.error",
-      syslog_severity = 0,
-      emoji = "\xF0\x9F\x9A\xA9"
-   }
-}
-
 -- ##############################################
 
 -- Groups for alert severities to obtain coarser-grained groups of finer-grained alert severities.
@@ -134,68 +55,9 @@ alert_consts.severity_groups = {
 
 -- ##############################################
 
--- See flow_consts.status_types in flow_consts for flow alerts
+alert_consts.alert_entities = alert_entities
 
--- Keep in sync with ntop_typedefs.h:AlertEntity
-alert_consts.alert_entities = {
-   interface = {
-    entity_id = 0,
-    label = "Interface",
-    pools = "interface_pools", -- modules/pools/interface_pools.lua
-   }, host = {
-    entity_id = 1,
-    label = "Host",
-    pools = "host_pools", -- modules/pools/host_pools.lua
-   }, network = {
-    entity_id = 2,
-    label = "Network",
-    pools = "local_network_pools", -- modules/pools/local_network_pools.lua
-   }, snmp_device = {
-    entity_id = 3,
-    label = "SNMP device",
-    pools = "snmp_device_pools", -- modules/pools/snmp_device_pools.lua
-   }, flow = {
-    entity_id = 4,
-    label = "Flow",
-    pools = "flow_pools", -- modules/pools/flow_pools.lua
-   }, mac = {
-    entity_id = 5,
-    label = "Device",
-    pools = "mac_pools", -- modules/pools/mac_pools.lua
-   }, host_pool = {
-    entity_id = 6,
-    label = "Host Pool",
-    pools = "host_pool_pools", -- modules/pools/host_pool_pools.lua
-   }, process = {
-    entity_id = 7,
-    label = "Process",
-    pools = "system_pools", -- modules/pools/system_pools.lua
-   }, user = {
-    entity_id = 8,
-    label = "User",
-    pools = "system_pools", -- modules/pools/system_pools.lua
-   }, influx_db = {
-    entity_id = 9,
-    label = "Influx DB",
-    pools = "system_pools", -- modules/pools/system_pools.lua
-   }, test = {
-    entity_id = 10,
-    label = "Test",
-    pools = "system_pools", -- modules/pools/system_pools.lua
-   }, category_lists = {
-    entity_id = 11,
-    label = "Category Lists",
-    pools = "system_pools", -- modules/pools/system_pools.lua
-   }, am_host = {
-    entity_id = 12,
-    label = "Active Monitoring Host",
-    pools = "active_monitoring_pools", -- modules/pools/active_monitoring_pools.lua
-   }, periodic_activity = {
-    entity_id = 13,
-    label = "Periodic Activity",
-    pools = "system_pools", -- modules/pools/system_pools.lua
-  }
-}
+-- ##############################################
 
 -- Keep in sync with C
 alert_consts.alerts_granularities = {
@@ -227,6 +89,27 @@ alert_consts.alerts_granularities = {
 
 -- ################################################################################
 
+-- This status is written inside SQLite column `alert_status`
+alert_consts.alert_status = {
+   ["historical"] = {
+      -- Default for alerts written to the database
+      alert_status_id = 0,
+   },
+   ["acknowledged"] = {
+      -- Alerts acknowledged
+      alert_status_id = 1,
+   },
+   ["engaged"] = {
+      -- Not used yet. Will be possibly used when managing engaged alerts inside sqlite
+      alert_status_id = 2,
+   },
+   ["any"] = {
+      alert_status_id = 3,
+   },
+}
+
+-- ################################################################################
+
 alert_consts.ids_rule_maker = {
   GPL = "GPL",
   SURICATA = "Suricata",
@@ -235,40 +118,45 @@ alert_consts.ids_rule_maker = {
 
 -- ##############################################
 
-alert_consts.alert_entities_id_to_key = {}
-alert_consts.alert_severities_id_to_key = {}
-alert_consts.alerts_granularities_id_to_key = {}
-alert_consts.alerts_granularities_seconds_to_key = {}
+local alert_entities_id_to_key = {}
+local alert_severities_id_to_key = {}
+local alerts_granularities_id_to_key = {}
+local alerts_granularities_seconds_to_key = {}
 
 local function initMappings()
    -- alert_entities_id_to_key
    for key, entity_info in pairs(alert_consts.alert_entities) do
-      alert_consts.alert_entities_id_to_key[entity_info.entity_id] = key
+      alert_entities_id_to_key[entity_info.entity_id] = key
    end
 
    -- alert_severities_id_to_key 
-   for key, severity_info in pairs(alert_consts.alert_severities) do
-      alert_consts.alert_severities_id_to_key[severity_info.severity_id] = key
+   for key, severity_info in pairs(alert_severities) do
+      alert_severities_id_to_key[severity_info.severity_id] = key
    end
 
    -- alerts_granularities_id_to_key 
    for key, granularity_info in pairs(alert_consts.alerts_granularities) do
-     alert_consts.alerts_granularities_id_to_key[granularity_info.granularity_id] = key
+     alerts_granularities_id_to_key[granularity_info.granularity_id] = key
    end
 
    -- alerts_granularities_seconds_to_key
    for key, granularity_info in pairs(alert_consts.alerts_granularities) do
-     alert_consts.alerts_granularities_seconds_to_key[granularity_info.granularity_seconds] = key
+     alerts_granularities_seconds_to_key[granularity_info.granularity_seconds] = key
    end
 end
 
 -- ##############################################
 
+function alert_consts.formatHostAlert(ifid, host, vlan)
+   return hostinfo2label({host = host, vlan = vlan})
+end
+
+-- ##############################################
+
 function alert_consts.formatAlertEntity(ifid, entity_type, entity_value)
    require "flow_utils"
    local value
    local epoch_begin, epoch_end = getAlertTimeBounds({alert_tstamp = os.time()})
-   local label = string.lower(alert_consts.alert_entities[entity_type].label)
 
    if entity_type == "host" then
       local host_info = hostkey2hostinfo(entity_value)
@@ -311,13 +199,18 @@ function alert_consts.formatAlertEntity(ifid, entity_type, entity_value)
       return localized
    else
       -- fallback
-      return label.." "..value
+      return value
    end
 end
 
 -- ##############################################
 
 function getMacUrl(mac)
+   if not mac then
+      tprint("getMacUrl(nil)")
+      tprint(debug.traceback()) 
+      return "" 
+   end
    return ntop.getHttpPrefix() .. "/lua/mac_details.lua?host=" .. mac
 end
 
@@ -330,6 +223,11 @@ end
 -- ##############################################
 
 function getHostPoolUrl(pool_id)
+   if not pool_id then
+      tprint("getHostPoolUrl(nil)")
+      tprint(debug.traceback())
+      return ""
+   end
    return ntop.getHttpPrefix() .. "/lua/hosts_stats.lua?pool=" .. pool_id
 end
 
@@ -379,7 +277,9 @@ function alert_consts.getDefinititionDirs()
 
    return({
 	 -- Path for ntopng-defined builtin alerts
-	 os_utils.fixPath(dirs.installdir .. "/scripts/lua/modules/alert_definitions"),
+	 os_utils.fixPath(dirs.installdir .. "/scripts/lua/modules/alert_definitions/flow"),
+	 os_utils.fixPath(dirs.installdir .. "/scripts/lua/modules/alert_definitions/host"),
+	 os_utils.fixPath(dirs.installdir .. "/scripts/lua/modules/alert_definitions/other"),
 	 -- Path for user-defined alerts written in plugins
 	 os_utils.fixPath(plugins_utils.getRuntimePath() .. "/alert_definitions"),
 	  }
@@ -390,12 +290,12 @@ end
 
 function alert_consts.alertEntityRaw(entity_id)
    entity_id = tonumber(entity_id)
-   return alert_consts.alert_entities_id_to_key[entity_id]
+   return alert_entities_id_to_key[entity_id]
 end
 
 function alert_consts.alertEntityById(entity_id)
    entity_id = tonumber(entity_id)
-   return alert_consts.alert_entities[alert_consts.alert_entities_id_to_key[entity_id]]
+   return alert_consts.alert_entities[alert_entities_id_to_key[entity_id]]
 end
 
 function alert_consts.alertEntity(v)
@@ -406,16 +306,15 @@ function alert_consts.alertEntityLabel(v)
   local entity_id = alert_consts.alertEntityRaw(v)
 
   if(entity_id) then
-    return(alert_consts.alert_entities[entity_id].label)
+    return i18n(alert_consts.alert_entities[entity_id].i18n_label)
   end
 end
 
 -- ##############################################
 
--- NOTE: flow alerts are formatted based on their status. See flow_consts.status_types.
 -- See alert_consts.resetDefinitions()
 alert_consts.alert_types = {}
-local alerts_by_id = {}
+local alerts_by_id = {} -- All available alerts keyed by entity_id and alert_id
 
 local function loadAlertsDefs()
    if(false) then
@@ -439,7 +338,7 @@ local function loadAlertsDefs()
 	       goto next_script
             end
 
-            if not alert_consts.loadDefinition(def_script, mod_fname, defs_dir) then
+            if not loadDefinition(def_script, mod_fname, defs_dir) then
 	       -- Retry reload
 	       package.loaded[mod_fname] = nil
 	    end
@@ -476,47 +375,67 @@ end
 
 -- ##############################################
 
-function alert_consts.loadDefinition(def_script, mod_fname, script_path)
+function loadDefinition(def_script, mod_fname, script_path)
    local required_fields = {"alert_key", "i18n_title", "icon"}
 
-   -- Check the required fields
+   -- Check the required meta table
+   if(def_script.meta == nil) then
+      traceError(TRACE_ERROR, TRACE_CONSOLE, string.format("Missing required table 'meta' in %s from %s", mod_fname, script_path))
+      return(false)
+   end
+
+   -- Check the required metadata fields
    for _, k in pairs(required_fields) do
-      if(def_script[k] == nil) then
-         traceError(TRACE_ERROR, TRACE_CONSOLE, string.format("Missing required field '%s' in %s from %s", k, mod_fname, script_path))
-         return(false)
+      if(def_script.meta[k] == nil) then
+	 traceError(TRACE_ERROR, TRACE_CONSOLE, string.format("Missing required field '%s' in %s from %s", k, mod_fname, script_path))
+	 return(false)
       end
    end
 
-   -- Sanity check: make sure this is a valid alert key
-   local parsed_alert_key, status = alert_keys.parse_alert_key(def_script.alert_key)
-   if not parsed_alert_key then
+   local alert_entity
+   if script_path:ends(os_utils.fixPath("/flow")) then
+      alert_entity = alert_entities.flow
+   elseif script_path:ends(os_utils.fixPath("/host")) then
+      alert_entity = alert_entities.host
+   else
+      -- TODO: migrate all. currently assumes other for non-flow non-host
+      alert_entity = alert_entities.other
+   end
+
+   local alert_key = def_script.meta.alert_key
+
+   if not alert_entity or not alert_key then
       traceError(TRACE_ERROR, TRACE_CONSOLE, string.format("Invalid alert key specified %s in %s from %s", status, mod_fname, script_path))
       return(false)
    end
 
-   if(alerts_by_id[parsed_alert_key] ~= nil) then
-      traceError(TRACE_ERROR, TRACE_CONSOLE, string.format("Alert key %d redefined, skipping in %s from %s", parsed_alert_key, mod_fname, script_path))
+   -- Sanity check: make sure the alert key is not redefined
+   local alert_entity_id = alert_entity.entity_id
+  
+   if alerts_by_id[alert_entity_id] and alerts_by_id[alert_entity_id][alert_key] then
+      traceError(TRACE_ERROR, TRACE_CONSOLE, string.format("Alert key %d redefined, skipping in %s from %s", alert_key, mod_fname, script_path))
       return(false)
    end
 
-   -- Save the original creator to wrap it with the aim of attaching the `alert_type`
-   -- This avoids repeating the alert type twice in every alert definition file
-   local cur_creator = def_script.creator
-   local creator = function(...)
-      local created = {}
-
-      if cur_creator then
-         created = cur_creator(...)
-      end
-
-      created["alert_type"] = def_script
-      return created
-   end
-
-   def_script.alert_key = parsed_alert_key
-   def_script.create = creator
+   -- Add alert metadata to the script
    alert_consts.alert_types[mod_fname] = def_script
-   alerts_by_id[parsed_alert_key] = mod_fname
+
+   if not alerts_by_id[alert_entity_id] then
+      alerts_by_id[alert_entity_id] = {}
+   end
+   alerts_by_id[alert_entity_id][alert_key] = mod_fname
+
+   -- Handle 'other' alerts
+   -- Note: some are used by multiple entities, defined under
+   -- meta in the alert definition
+   if def_script.meta['entities'] then
+      for _, entity in ipairs(def_script.meta['entities']) do
+         if not alerts_by_id[entity.entity_id] then
+            alerts_by_id[entity.entity_id] = {}
+         end
+         alerts_by_id[entity.entity_id][alert_key] = mod_fname
+      end
+   end
 
    -- Success
    return(true)
@@ -524,69 +443,143 @@ end
  
 -- ##############################################
 
-function alert_consts.alertTypeLabel(v, nohtml)
-   local alert_key = alert_consts.alertTypeRaw(v)
+function alert_consts.alertTypeLabel(alert_id, nohtml, alert_entity_id)
+   local alert_key = alert_consts.getAlertType(alert_id, alert_entity_id)
 
    if(alert_key) then
       local type_info = alert_consts.alert_types[alert_key]
-      local title = i18n(type_info.i18n_title) or type_info.i18n_title
+      -- TODO: .meta is the new format, OR are for compatibility and can be removed when migration is done
+      local title = i18n(type_info.i18n_title or type_info.meta.i18n_title) or type_info.i18n_title or type_info.meta.i18n_title
 
       if(nohtml) then
         return(title)
       else
-        return(string.format('<i class="%s"></i> %s', type_info.icon, title))
+        return(string.format('<i class="%s"></i> %s', type_info.icon or type_info.meta.icon, shortenString(title)))
       end
    end
 
    return(i18n("unknown"))
 end
- 
+
+-- ##############################################
+
+-- @brief Given a flow status identified by `status_key`, returns an icon associated to the severity
+-- @param `status info`, A human readable (localized) status info
+-- @param `alerted_severity`, Integer severity of the alert associated to this status
+-- @return The HTML with icon and ALT text, or empty if no icon is available
+function alert_consts.alertTypeIcon(alert_info, alerted_severity)
+   local severity = alert_consts.alertSeverityById(alerted_severity)
+
+   if severity then
+      local alert_consts = require "alert_consts"
+      return "<i class='"..severity.icon.."' title='"..noHtml(alert_consts.alertTypeLabel(alert_info, true)) .."'></i> "
+   end
+
+   return ""
+end
+
 -- ##############################################
 
 function alert_consts.alertType(v)
    if(alert_consts.alert_types[v] == nil) then
       tprint(debug.traceback())
    end
- 
-   return(alert_consts.alert_types[v].alert_key)
+
+   local res = alert_consts.alert_types[v].alert_key
+
+   if not res and alert_consts.alert_types[v].meta then
+      -- TODO AM: attempt at looking inside new implementation `meta`
+      res = alert_consts.alert_types[v].meta.alert_key
+   end
+
+   return res
  end
- 
+
 -- ##############################################
 
-function alert_consts.getAlertType(alert_key)
-    return(alerts_by_id[tonumber(alert_key)])
+function alert_consts.getAlertType(alert_key, alert_entity_id)
+   -- Make sure we are working with numbers
+   alert_key = tonumber(alert_key)
+   alert_entity_id = tonumber(alert_entity_id)
+
+   if alert_entity_id and alerts_by_id[alert_entity_id] and alerts_by_id[alert_entity_id][alert_key] then
+      return alerts_by_id[alert_entity_id][alert_key]
+   end
+
+   -- TODO: remove fallbacks when all alerts in alert_keys.lua will be migrated and will have their own entity specified
+
+   -- Fallback 01: if no alert_entity_id is passed, alert_entity is assumed to be flow.
+   if alerts_by_id[alert_entities.flow.entity_id][alert_key] then
+      return alerts_by_id[alert_entities.flow.entity_id][alert_key]
+   end
+
+   -- Fallback 02: if no alert_entity_id is passed, alert_entity is assumed to be other.
+   if alerts_by_id[alert_entities.other.entity_id][alert_key] then
+      return alerts_by_id[alert_entities.other.entity_id][alert_key]
+   end
+end
+
+-- ##############################################
+
+function alert_consts.getAlertTypes(alert_entity_id)
+   return alerts_by_id[alert_entity_id]
+end
+
+-- ##############################################
+
+function alert_consts.alert_type_info_asc(a, b)
+   return (a.label:upper() < b.label:upper())
+end
+
+function alert_consts.getAlertTypesInfo(alert_entity_id)
+   local alert_types = alert_consts.getAlertTypes(alert_entity_id)
+
+   if not alert_types then
+      return {}
+   end
+
+   local alert_types_info = {}
+   for alert_id, alert_name in pairs(alert_types) do
+      alert_types_info[alert_id] = {
+         alert_id = alert_id,
+         name = alert_name,
+         label = alert_consts.alertTypeLabel(alert_id, true, alert_entity_id),
+      }
+   end
+
+   return alert_types_info
 end
 
 -- ##############################################
 
 function alert_consts.alertLevelToSyslogLevel(v)
-  return alert_consts.alert_severities[v].syslog_severity
+   return alert_severities[alert_consts.alertSeverityRaw(v)].syslog_severity
 end
 
 -- ################################################################################
 
 function alert_consts.alertSeverityRaw(severity_id)
    severity_id = tonumber(severity_id)
-   return alert_consts.alert_severities_id_to_key[severity_id] 
+   return alert_severities_id_to_key[severity_id] 
 end
 
  -- ################################################################################
 
-function alert_consts.alertSeverityLabel(v, nohtml, emoji)
-   local severity_id = alert_consts.alertSeverityRaw(v)
+function alert_consts.alertSeverityLabel(score, nohtml, emoji)
+   local severity_id = alert_consts.alertSeverityRaw(ntop.mapScoreToSeverity(score))
 
    if(severity_id) then
-      local severity_info = alert_consts.alert_severities[severity_id]
+      local severity_info = alert_severities[severity_id]
       local title = i18n(severity_info.i18n_title) or severity_info.i18n_title
 
       if(emoji) then
-	 title = (severity_info.emoji or "").. " " .. title
+	      title = (severity_info.emoji or "").. " " .. title
       end
       
       if(nohtml) then
         return(title)
       else
-        return(string.format('<span class="badge %s">%s</span>', severity_info.label, title))
+        return(string.format('<span class="badge %s" title="%s">%s</span>', severity_info.label, title, title:sub(1, 1)))
       end
    end
 
@@ -596,7 +589,7 @@ end
 -- ################################################################################
 
 function alert_consts.alertSeverity(v)
-   return(alert_consts.alert_severities[v].severity_id)
+   return(alert_severities[v].severity_id)
 end
  
 -- ################################################################################
@@ -604,16 +597,9 @@ end
 function alert_consts.alertSeverityById(severity_id)
    local key = alert_consts.alertSeverityRaw(severity_id)
    if key == nil then 
-      return alert_consts.alert_severities.error
+      return alert_severities.error
    end
-   return(alert_consts.alert_severities[key])
-end
-
--- ################################################################################
- 
-function alert_consts.alertTypeRaw(type_id)
-   type_id = tonumber(type_id)
-   return alerts_by_id[type_id]
+   return(alert_severities[key])
 end
 
  -- ################################################################################
@@ -621,7 +607,7 @@ end
 -- Rename engine -> granulariy
 local function alertEngineRaw(granularity_id)
    granularity_id = tonumber(granularity_id)
-   return alert_consts.alerts_granularities_id_to_key[granularity_id] 
+   return alerts_granularities_id_to_key[granularity_id] 
 end
  
 -- ################################################################################
@@ -666,7 +652,7 @@ end
 
 function alert_consts.sec2granularity(seconds)
    seconds = tonumber(seconds)
-   return alert_consts.alerts_granularities_seconds_to_key[seconds]
+   return alerts_granularities_seconds_to_key[seconds]
 end
  
 -- Load definitions now
