@@ -1,219 +1,9 @@
 --
--- (C) 2019-20 - ntop.org
+-- (C) 2019-21 - ntop.org
 --
 -- This file contains flow related constats
 
 local flow_consts = {}
-local status_keys = require "flow_keys"
-local locales_utils = require "locales_utils"
-local format_utils  = require "format_utils"
-local os_utils = require("os_utils")
-local plugins_utils = require("plugins_utils")
-local lua_path_utils = require "lua_path_utils"
-
-flow_consts.max_score = 1024 -- Keep in sync with SCORE_MAX_SCRIPT_VALUE in ntop_defines.h
-
--- ################################################################################
-
-function flow_consts.getDefinititionDirs()
-   local dirs = ntop.getDirs()
-
-   return({
-	 -- Path for ntopng-defined builtin flow status definitions
-	 os_utils.fixPath(dirs.installdir .. "/scripts/lua/modules/flow_status_definitions"),
-	 -- Path for user-defined alerts written in plugins
-	 os_utils.fixPath(plugins_utils.getRuntimePath() .. "/status_definitions"),
-	  }
-   )
-end
-
--- ################################################################################
-
--- See flow_consts.resetDefinitions()
-flow_consts.status_types = {}
-local status_by_id = {}
-local status_key_by_id = {}
-
-local function loadStatusDefs()
-   if(false) then
-      if(string.find(debug.traceback(), "second.lua")) then
-         traceError(TRACE_WARNING, TRACE_CONSOLE, "second.lua is loading flow_consts.lua. This will slow it down!")
-      end
-   end
-
-   local defs_dirs = flow_consts.getDefinititionDirs()
-
-   for _, defs_dir in pairs(defs_dirs) do
-      lua_path_utils.package_path_prepend(defs_dir)
-
-      for fname in pairs(ntop.readdir(defs_dir)) do
-	 if ends(fname, ".lua") then
-	    local mod_fname = string.sub(fname, 1, string.len(fname) - 4)
-	    local def_script = require(mod_fname)
-
-	    if(def_script == nil) then
-	       traceError(TRACE_ERROR, TRACE_CONSOLE, string.format("Error loading status definition from %s", mod_fname))
-	       goto next_script
-	    end
-
-	    if not flow_consts.loadDefinition(def_script, mod_fname, defs_dir) then
-	       -- Retry reload
-	       package.loaded[mod_fname] = nil
-	    end
-	 end
-
-	 ::next_script::
-      end
-   end
-end
-
--- ################################################################################
-
--- @brief Cleanup all the currently loaded flow status definitions from the current vm.
---        This will cause subsequent new `require`s to be performed.
---        It is only necessary to call this method when flow status definitions are changed,
---        i.e., upon plugins reload, or when a license expires.
-function flow_consts.resetDefinitions()
-   flow_consts.status_types = {}
-   status_by_id = {}
-   status_key_by_id = {}
-
-   local defs_dirs = flow_consts.getDefinititionDirs()
-
-   for _, defs_dir in pairs(defs_dirs) do
-      lua_path_utils.package_path_prepend(defs_dir)
-
-      for fname in pairs(ntop.readdir(defs_dir)) do
-	 if ends(fname, ".lua") then
-	    local mod_fname = string.sub(fname, 1, string.len(fname) - 4)
-	    package.loaded[mod_fname] = nil
-	 end
-      end
-   end
-end
-
--- ################################################################################
-
-function flow_consts.loadDefinition(def_script, mod_fname, script_path)
-   local required_fields = {"status_key", "alert_severity", "alert_type", "i18n_title"}
-
-   -- print("Loading "..script_path.."\n")
-   
-   -- Check the required fields
-   for _, k in pairs(required_fields) do
-      if(def_script[k] == nil) then
-	 traceError(TRACE_ERROR, TRACE_CONSOLE, string.format("Missing required field '%s' in %s from %s", k, mod_fname, script_path))
-	 return(false)
-      end
-   end
-
-   local def_id = def_script.status_key
-
-   if(def_id == nil) then
-      traceError(TRACE_ERROR, TRACE_CONSOLE, string.format("Missing status ID in %s from %s", mod_fname, script_path))
-      return(false)
-   end
-
-   -- Sanity check: make sure this is a valid status id
-   local valid = false
-   for pen, pen_keys in pairs(status_keys) do
-      for _, key in pairs(pen_keys) do
-	 if def_id == key then
-	    valid = true
-	    break
-	 end
-      end
-   end
-
-   if not valid then
-      traceError(TRACE_ERROR, TRACE_CONSOLE, string.format("Invalid status ID in %s from %s", mod_fname, script_path))
-      return(false)
-   end
-
-   if(status_by_id[def_id] ~= nil) then
-      traceError(TRACE_ERROR, TRACE_CONSOLE, string.format("Status ID %d redefined, skipping in %s from %s", def_id,  mod_fname, script_path))
-      return(false)
-   end
-
-   -- If this flow status has an alert associated,
-   -- the alert creator is attached straigth to this flow for the flow.tirggerStatus
-   -- Save the alert creator and wrap it to add the current script as a `status_key`.
-   -- This makes the creator self contained and avoids repetition in the flow status definition files
-   local creator = function(...)
-      local created = {}
-
-      if def_script.alert_type and def_script.alert_type.creator then
-	 created = def_script.alert_type.create(...)
-      end
-
-      created["status_type"] = def_script
-      return created
-   end
-
-   -- Success
-   def_script.status_key = def_id
-   def_script.create = creator
-   status_by_id[def_id] = def_script
-   status_key_by_id[def_id] = mod_fname
-   flow_consts.status_types[mod_fname] = def_script
-
-   return(true)
-end
-
--- ################################################################################
-
-function flow_consts.getStatusDescription(status_key, flowstatus_info)
-   local status_def = status_by_id[tonumber(status_key)]
-
-   if(status_def == nil) then
-      return(i18n("flow_details.unknown_status",{status=status}))
-   end
-
-   if(type(status_def.i18n_description) == "function") then
-      -- formatter function
-      return(status_def.i18n_description(flowstatus_info))
-   elseif(status_def.i18n_description ~= nil) then
-      return(i18n(status_def.i18n_description) or status_def.i18n_description)
-   else
-      return(i18n(status_def.i18n_title) or status_def.i18n_title)
-   end
-end
-
--- ################################################################################
-
--- @brief Given a flow status identified by `status_key`, returns an icon associated to the severity
--- @param `status_key` A flow status identified
--- @param `status info`, A human readable (localized) status info
--- @return The HTML with icon and ALT text, or empty if no icon is available
-function flow_consts.getStatusIcon(status_key, status_info)
-   local status_def = status_by_id[tonumber(status_key)]
-
-   -- If the status has no severity associated or the severity has no icon, then return
-   if not status_def or not status_def.alert_severity or not status_def.alert_severity.icon then
-      return ""
-   end
-
-   -- Return the icon
-   return "<i class='"..status_def.alert_severity.icon.."' title='"..noHtml(status_info) .."'></i> "
-end
-
--- ################################################################################
-
-function flow_consts.getStatusTitle(status_key)
-   local status_def = status_by_id[tonumber(status_key)]
-
-   if(status_def == nil) then
-      return(i18n("flow_details.unknown_status",{status=status}))
-   end
-
-   return(i18n(status_def.i18n_title))
-end
-
--- ################################################################################
-
-function flow_consts.getStatusType(status_key)
-   return(status_key_by_id[tonumber(status_key)])
-end
 
 -- ################################################################################
 
@@ -287,8 +77,8 @@ flow_consts.flow_fields_description = {
    ["PACKET_SECTION_OFFSET"] = i18n("flow_fields_description.packet_section_offset"),
    ["SAMPLED_PACKET_SIZE"] = i18n("flow_fields_description.sampled_packet_size"),
    ["SAMPLED_PACKET_ID"] = i18n("flow_fields_description.sampled_packet_id"),
-   ["EXPORTER_IPV4_ADDRESS"] = i18n("flow_fields_description.exporter_ipv4_address"),
-   ["EXPORTER_IPV6_ADDRESS"] = i18n("flow_fields_description.exporter_ipv6_address"),
+   ["EXPORTER_IPV4_ADDRESS"] = i18n("flow_fields_description.probe_ipv4_address"),
+   ["EXPORTER_IPV6_ADDRESS"] = i18n("flow_fields_description.probe_ipv6_address"),
    ["FLOW_END_REASON"] = i18n("flow_fields_description.flow_end_reason"),
    ["FLOW_ID"] = i18n("flow_fields_description.flow_id"),
    ["FLOW_START_SEC"] = i18n("flow_fields_description.flow_start_sec"),
@@ -705,6 +495,33 @@ flow_consts.flow_fields_description = {
 
    -- Misc
    ["COMMUNITY_ID"] = i18n("flow_fields_description.community_id"),
+   ["FLOW_VERDICT"] = i18n("flow_fields_description.flow_verdict"),
+   ["L7_RISK_SCORE"] = i18n("flow_fields_description.l7_risk_score"),
+   
+   -- Numeric fields not handled by nProbe
+   ["25"]  =  i18n("flow_fields_description.ip_lenght_minimum"),
+   ["26"]  =  i18n("flow_fields_description.ip_lenght_maximum"),
+   ["422"] =  i18n("flow_fields_description.minimumLayer2TotalLength"),
+   ["423"] =  i18n("flow_fields_description.maximumLayer2TotalLength"),
+   ["428"] =  i18n("flow_fields_description.layer2OctetDeltaSumOfSquares"),
+   ["429"] =  i18n("flow_fields_description.layer2OctetTotalSumOfSquares"),
+   ["430"] =  i18n("flow_fields_description.layer2FrameDeltaCount"),
+   ["431"] =  i18n("flow_fields_description.layer2FrameTotalCount"),
+   ["184"]   =  i18n("flow_fields_description.tcpSeqNum"),
+   ["185"]   =  i18n("flow_fields_description.tcpAckNum"),
+   ["186"]   =  i18n("flow_fields_description.tcpWindowSize"),
+   ["187"]   =  i18n("flow_fields_description.tcpUrgentPtr"),
+   ["195"]   =  i18n("flow_fields_description.ipDSCP"),
+   ["196"]   =  i18n("flow_fields_description.ipPrecendence"),
+   ["204"]   =  i18n("flow_fields_description.ipPayloadLenght"),
+   ["245"]   =  i18n("flow_fields_description.dot1qCustomerVlanId"),
+   ["457"]   =  i18n("flow_fields_description.httpStatusCode"),
+   ["459"]   =  i18n("flow_fields_description.httpRequestMethod"),
+   ["460"]   =  i18n("flow_fields_description.httpRequestHost"),
+   ["461"]   =  i18n("flow_fields_description.httpRequestTarget"),
+   ["462"]   =  i18n("flow_fields_description.httpMessageVersion"),
+   ["468"]   =  i18n("flow_fields_description.httpUserAgent"),
+
 }
 
 -- ################################################################################
@@ -1173,21 +990,4 @@ flow_consts.mobile_country_code = {
    ["648"] = "Zimbabwe (Republic of)",
 }
 
--- ################################################################################
-
-local function dumpStatusDefs()
-   for _, a in pairsByKeys(status_by_id) do
-      print("[status_key: ".. a.status_key .."][title: ".. a.i18n_title.."]\n")
-      -- tprint(k)
-   end
-end
-
--- ################################################################################
-
--- Load definitions now
-loadStatusDefs()
-
--- Print definitions: enable for debugging
--- dumpStatusDefs()
-
 return flow_consts
