@@ -1,5 +1,5 @@
 --
--- (C) 2017-20 - ntop.org
+-- (C) 2017-21 - ntop.org
 --
 dirs = ntop.getDirs()
 
@@ -142,7 +142,7 @@ function host_pools_migration.import(pools, ifid)
       if pool.name == existing_pool.name then
         -- Same name, delete the old pool and reuse the id
         pool.id = existing_pool.id
-        host_pools_migration.emptyPool(ifid, existing_pool.id) 
+        host_pools_migration.emptyPool(ifid, existing_pool.id)
         host_pools_migration.deletePool(ifid, existing_pool.id)
       end
     end
@@ -335,11 +335,6 @@ function host_pools_migration.deletePoolMember(ifid, pool_id, member_and_vlan)
 
   local members_key = get_pool_members_key(ifid, pool_id)
 
-  -- Possible delete volatile member
-  if ntop.isPro() then
-    interface.removeVolatileMemberFromPool(member_and_vlan, tonumber(pool_id))
-  end
-
   -- Possible delete non-volatile member
   ntop.delMembersCache(members_key, member_and_vlan)
 end
@@ -384,25 +379,11 @@ function host_pools_migration.getPoolMembers(ifid, pool_id)
   local members = {}
 
   local all_members = ntop.getMembersCache(members_key) or {}
-  local volatile = {}
-
-  if ntop.isPro() then
-    for _,v in pairs(interface.getHostPoolsVolatileMembers()[tonumber(pool_id)] or {}) do
-      if not v.expired then
-        all_members[#all_members + 1] = v["member"]
-        volatile[v["member"]] = v["residual_lifetime"]
-      end
-    end
-  end
 
   for _,v in pairsByValues(all_members, asc) do
     local hostinfo = hostkey2hostinfo(v)
-    local residual_lifetime = NULL
-    if volatile[v] ~= nil then
-      residual_lifetime = volatile[v];
-    end
 
-    members[#members + 1] = {address=hostinfo["host"], vlan=hostinfo["vlan"], key=v, residual=residual_lifetime}
+    members[#members + 1] = {address=hostinfo["host"], vlan=hostinfo["vlan"], key=v}
   end
 
   return members
@@ -476,13 +457,6 @@ end
 function host_pools_migration.emptyPool(ifid, pool_id)
   local members_key = get_pool_members_key(ifid, pool_id)
 
-  if ntop.isPro() then
-    -- Remove volatile members
-    for _,v in pairs(interface.getHostPoolsVolatileMembers()[tonumber(pool_id)] or {}) do
-      interface.removeVolatileMemberFromPool(v.member, tonumber(pool_id))
-    end
-  end
-
   -- Remove non-volatile members
   ntop.delCache(members_key)
 end
@@ -538,18 +512,6 @@ function host_pools_migration.getUndeletablePools(ifid)
   return pools
 end
 
-function host_pools_migration.purgeExpiredPoolsMembers()
-   local ifnames = interface.getIfNames()
-
-   for _, ifname in pairs(ifnames) do
-      interface.select(ifname)
-
-      -- Currently, volatile pool members are no longer used,
-      -- so there's no need to purge them.
-      -- interface.purgeExpiredPoolsMembers()
-   end
-end
-
 function host_pools_migration.getRRDBase(ifid, pool_id)
   local dirs = ntop.getDirs()
   return os_utils.fixPath(dirs.workingdir .. "/" .. ifid .. "/host_pools/" .. pool_id)
@@ -602,7 +564,7 @@ function host_pools_migration.hostpool2record(ifid, pool_id, pool)
 
    local sent2rcvd = round((pool["bytes.sent"] * 100) / (pool["bytes.sent"] + pool["bytes.rcvd"]), 0)
    record["column_breakdown"] = "<div class='progress'><div class='progress-bar bg-warning' style='width: "
-      .. sent2rcvd .."%;'>Sent</div><div class='progress-bar bg-info' style='width: " .. (100-sent2rcvd) .. "%;'>Rcvd</div></div>"
+      .. sent2rcvd .."%;'>Sent</div><div class='progress-bar bg-success' style='width: " .. (100-sent2rcvd) .. "%;'>Rcvd</div></div>"
 
    if(throughput_type == "pps") then
       record["column_thpt"] = pktsToSize(pool["throughput_pps"])
@@ -646,7 +608,7 @@ function host_pools_migration.printQuotas(pool_id, host, page_params)
   if empty then
     local url = "/lua/pro/nedge/admin/nf_edit_user.lua?page=protocols&username=" .. host_pools_migration.poolIdToUsername(pool_id)
 
-    print("<div class=\"alert alert alert-danger\"><img src=".. ntop.getHttpPrefix() .. "/img/warning.png>"..i18n("shaping.no_quota_data")..
+    print("<div class=\"alert alert alert-danger\"><i class='fas fa-exclamation-triangle fa-lg fa-ntopng-warning'></i> "..i18n("shaping.no_quota_data")..
       ". " .. i18n("host_pools.create_new_quotas_here", {url=ntop.getHttpPrefix()..url}) .. "</div>")
   else
     print[[
@@ -661,7 +623,6 @@ function host_pools_migration.printQuotas(pool_id, host, page_params)
     <tbody id="pool_quotas_ndpi_tbody">
     </tbody>
     </table>
-
     <script>
       function update_ndpi_table() {
         $.ajax({
