@@ -1,5 +1,5 @@
 --
--- (C) 2014-18 - ntop.org
+-- (C) 2014-21 - ntop.org
 --
 
 -- This file contains the description of all functions
@@ -57,10 +57,10 @@ function isSubpageAvailable(subpage, show_advanced_prefs)
   if show_advanced_prefs == nil then
     show_advanced_prefs = toboolean(ntop.getPref(show_advanced_prefs_key))
   end
-
   if (subpage.hidden) or
      ((subpage.advanced) and (not show_advanced_prefs)) or
      ((subpage.pro_only) and (not ntop.isPro())) or
+     (subpage.enterprise_l_only and (not info["version.enterprise_l_edition"])) or
      ((subpage.enterprise_only) and (not info["version.enterprise_edition"]) and (not have_nedge)) or
      (subpage.nedge_hidden) and (have_nedge) then
     return false
@@ -75,7 +75,7 @@ function prefsGetActiveSubpage(show_advanced_prefs, tab)
   for _, subpage in ipairs(menu_subpages) do
     if not isSubpageAvailable(subpage, show_advanced_prefs) then
       subpage.hidden = true
-      
+
       if subpage.id == tab then
         -- will set to default
         tab = nil
@@ -101,10 +101,11 @@ function prefsGetActiveSubpage(show_advanced_prefs, tab)
 end
 
 function printMenuSubpages(tab)
+
   for _, subpage in ipairs(menu_subpages) do
     if not subpage.hidden then
       local url = ternary(subpage.disabled, "#", ntop.getHttpPrefix() .. [[/lua/admin/prefs.lua?tab=]] .. (subpage.id))
-      print[[<a href="]] print(url) print[[" class="list-group-item menu-item]]
+      print[[<a href="]] print(url) print[[" class="list-group-item list-group-item-action]]
 
       if(tab == subpage.id) then
         print(" active")
@@ -119,15 +120,12 @@ end
 
 -- ############################################
 
--- notify ntopng upon preference changes
-function notifyNtopng(key)
+--- Notify ntopng upon preference changes
+function notifyNtopng(key, value)
     if key == nil then return end
     -- notify runtime ntopng configuration changes
-    if string.starts(key, 'nagios') then
-        if verbose then io.write('notifying ntopng upon nagios pref change\n') end
-        ntop.reloadNagiosConfig()
-    elseif string.starts(key, 'toggle_logging_level') then
-        if verbose then io.write('notifying ntopng upon logging level pref change\n') end 
+    if string.starts(key, 'toggle_logging_level') then
+        if verbose then io.write('notifying ntopng upon logging level pref change\n') end
         ntop.setLoggingLevel(value)
     end
 end
@@ -146,10 +144,10 @@ function prefsResolutionButtons(fmt, value, fixed_id, format_spec, max_val)
     options_ctr = options_ctr + 1
   end
 
-  local res = makeResolutionButtons(format_spec or FMT_TO_DATA_TIME, ctrl_id, fmt, value, {classes={"pull-right"}}, max_val)
+  local res = makeResolutionButtons(format_spec or FMT_TO_DATA_TIME, ctrl_id, fmt, value, {classes={"float-right"}}, max_val)
 
   res.value = truncate(res.value)
-  
+
   print(res.html)
   print("<script>")
   if not options_script_loaded then
@@ -243,6 +241,30 @@ function prefsInputFieldPrefs(label, comment, prekey, key, default_value, _input
     end
   end
 
+  if extra.minlength ~= nil then
+    if extra.tformat ~= nil then
+      attributes["data-minlength"] = extra.minlength
+    else
+      attributes["minlength"] = extra.minlength
+    end
+  end
+
+  if extra.maxlength ~= nil then
+    if extra.tformat ~= nil then
+      attributes["data-maxlength"] = extra.maxlength
+    else
+      attributes["maxlength"] = extra.maxlength
+    end
+  end
+
+  if extra.step ~= nil then
+    if extra.tformat ~= nil then
+      attributes["data-step"] = extra.step
+    else
+      attributes["step"] = extra.step
+    end
+  end
+
   if extra.disabled == true then attributes["disabled"] = "disabled" end
   if extra.required == true then attributes["required"] = "" end
   if extra.pattern ~= nil then attributes["pattern"] = extra.pattern end
@@ -264,7 +286,7 @@ function prefsInputFieldPrefs(label, comment, prekey, key, default_value, _input
 
   print [[
     <td align=right>
-      <table class="form-group" style="margin-bottom: 0; min-width:22em;">
+      <table class="table table-borderless form-group mb-3" style="margin-bottom: 0; min-width:22em;">
         <tr>
           <td width="100%;"></td>
           <td style="vertical-align:top;">]]
@@ -298,7 +320,7 @@ function prefsInputFieldPrefs(label, comment, prekey, key, default_value, _input
         </tr>
         <tr>
           <td colspan="3" style="padding:0;">
-            <div class="help-block with-errors text-right" style="height:1em;"></div>
+            <div class="help-block with-errors text-end" style="height:1em;"></div>
           </td>
         </tr>
       </table>
@@ -338,7 +360,7 @@ function prefsDropdownFieldPrefs(label, comment, key, values, default_value, sho
 
   print [[
     <td align=right>
-      <table class="form-group" style="margin-bottom: 0; min-width:22em;">
+      <table class="form-group mb-3" style="margin-bottom: 0; min-width:22em;">
         <tr>
           <td width="100%;"></td>]]
 
@@ -355,7 +377,7 @@ function prefsDropdownFieldPrefs(label, comment, key, values, default_value, sho
 
       print[[
           <td style="vertical-align:top; padding-left: 2em;">
-            <select id="id_input_]] print(key)  print [[" class="form-control" ]] print(table.tconcat(attributes, "=", " ", nil, '"')) print[[ name="]] print(key) print [[" style="]] print(table.tconcat(style, ":", "; ", ";")) print[[" value="]] print((value or '')..'"') print[[>]]
+            <select id="id_input_]] print(key)  print [[" class="form-select" ]] print(table.tconcat(attributes, "=", " ", nil, '"')) print[[ name="]] print(key) print [[" style="]] print(table.tconcat(style, ":", "; ", ";")) print[[" value="]] print((value or '')..'"') print[[>]]
       if extra.keys == nil then
          for _, optname in pairs(values) do
 	 print("<option " .. ternary(optname == default_value, "selected", "") .. ">"..optname.."</option>")
@@ -373,7 +395,7 @@ function prefsDropdownFieldPrefs(label, comment, key, values, default_value, sho
         </tr>
         <tr>
           <td colspan="3" style="padding:0;">
-            <div class="help-block with-errors text-right" style="height:1em;"></div>
+            <div class="help-block with-errors text-end" style="height:1em;"></div>
           </td>
         </tr>
       </table>
@@ -408,12 +430,12 @@ function toggleTableButton(label, comment, on_label, on_value, on_color , off_la
   -- Read it anyway to
   if(value == off_value) then
     rev_value  = on_value
-    on_active  = "btn-default"
+    on_active  = "btn-secondary"
     off_active = "btn-"..off_color.." active"
   else
     rev_value  = off_value
     on_active  = "btn-"..on_color.." active"
-    off_active = "btn-default"
+    off_active = "btn-secondary"
   end
 
   if(label ~= "") then print('<tr><td width=50%><strong>'..label..'</strong><p><small>'..comment..'</small></td><td align=right>\n') end
@@ -428,8 +450,28 @@ function toggleTableButton(label, comment, on_label, on_value, on_color , off_la
   return(value)
 end
 
-function toggleTableButtonPrefs(label, comment, on_label, on_value, on_color , off_label, off_value, off_color, submit_field,
-                                redis_key, default_value, disabled, elementToSwitch, hideOn, showElement, javascriptAfterSwitch)
+local function printNestedToSwitchLogic(nested_to_switch, submit_field)
+  if((type(nested_to_switch) ~= "table") or (table.empty(nested_to_switch))) then
+    return
+  end
+
+  for _, item in ipairs(nested_to_switch) do
+    print[[
+      if(($("#]] print(submit_field) print[[").val() == "]] print(item.pref_enabled_value or "1") print[[") &&
+         ($("#]] print(item.parent) print[[").val() == "]] print(item.parent_enabled_value) print[["))
+        $("#]] print(item.input) print[[").css("display", "table-row");
+      else
+        $("#]] print(item.input) print[[").css("display", "none");
+    ]]
+  end
+end
+
+local function toggleTableButtonPrefs(label, comment, on_label, on_value, on_color , off_label, off_value, off_color, submit_field,
+                                redis_key, default_value, disabled, elementToSwitch, hideOn, showElement, nested_to_switch)
+
+
+ local value
+
  if not skip_redis then
   value = ntop.getPref(redis_key)
   if(_POST[submit_field] ~= nil) then
@@ -460,13 +502,8 @@ function toggleTableButtonPrefs(label, comment, on_label, on_value, on_color , o
   end
 
   -- Read it anyway to
-  if(value == off_value) then
-    on_active  = "btn-default"
-    off_active = "btn-"..off_color.." active"
-  else
+  if(value ~= off_value) then
     value = on_value
-    on_active  = "btn-"..on_color.." active"
-    off_active = "btn-default"
   end
 
   local objRow = ""
@@ -476,22 +513,34 @@ function toggleTableButtonPrefs(label, comment, on_label, on_value, on_color , o
     objRow = " style=\"display:table-row\""
   end
   if(label ~= "") then print('<tr id="row_'..submit_field..'"'..objRow..'><td width=50%><strong>'..label..'</strong><p><small>'..comment..'</small></td><td align=right>\n') end
-  print('<div class="btn-group btn-toggle">')
-  print('<button type="button" onclick="'..submit_field..'_functionOn()" id="'..submit_field..'_on_id" '..disabled..' class="btn btn-sm  '..on_active..'">'..on_label..'</button>')
-  print('<button type="button" onclick="'..submit_field..'_functionOff()" id="'..submit_field..'_off_id" '..disabled..' class="btn btn-sm '..off_active..'">'..off_label..'</button></div>\n')
-  print('<input type=hidden id="'..submit_field..'_input" name='..submit_field..' value="'..value..'"/>\n')
-  if(label ~= "") then print('</td></tr>') end
-  print('\n')
-  print('<script>\n')
-  print[[function ]] print(submit_field) print [[_functionOn(){
-    var classOn = document.getElementById("]] print(submit_field) print [[_on_id");
-    var classOff = document.getElementById("]] print(submit_field) print [[_off_id");
-    classOn.removeAttribute("class");
-    classOff.removeAttribute("class");
-    classOn.setAttribute("class", "btn btn-sm btn-]]print(on_color) print[[ active");
-    classOff.setAttribute("class", "btn btn-sm btn-default");
 
-    $("#]] print(submit_field) print [[_input").val("]] print(on_value) print[[").trigger('change');]]
+  print([[
+    <div class="form-switch">
+      <input ]].. (value == off_value and '' or 'checked') ..[[ type="checkbox" class="form-check-input" id="check-]].. submit_field ..[[">
+      <label class="form-check-label" for="check-]].. submit_field ..[["></label>
+      <input hidden id="input-]].. submit_field ..[[" name="]].. submit_field ..[[" value="]].. value ..[[">
+  ]])
+  print([[</div>]])
+  if(label ~= "") then print('</td></tr>') end
+  print('<script type="text/javascript">')
+
+  print([[
+    $("#check-]].. submit_field.. [[").change(function(e) {
+
+      const value = $(this).is(":checked");
+
+      if (value) {
+        ]]..submit_field..[[_functionOn();
+      }
+      else {
+        ]]..submit_field..[[_functionOff();
+      }
+    });
+  ]])
+
+  print[[function ]] print(submit_field) print [[_functionOn(){]]
+    print([[$(`#input-]].. submit_field ..[[`).val("]].. on_value ..[[");]])
+
     if elementToSwitch ~= nil then
       for element = 1, #elementToSwitch do
         if ((hideOn == nil) or (hideOn == false)) then
@@ -502,21 +551,16 @@ function toggleTableButtonPrefs(label, comment, on_label, on_value, on_color , o
       end
     end
 
-    if javascriptAfterSwitch ~= nil then
-      print(javascriptAfterSwitch)
-    end
+    printNestedToSwitchLogic(nested_to_switch, "input-" .. submit_field)
+
     print[[
   }
   ]]
   print[[
-  function ]] print(submit_field) print [[_functionOff(){
-    var classOn = document.getElementById("]] print(submit_field) print [[_on_id");
-    var classOff = document.getElementById("]] print(submit_field) print [[_off_id");
-    classOn.removeAttribute("class");
-    classOff.removeAttribute("class");
-    classOn.setAttribute("class", "btn btn-sm btn-default");
-    classOff.setAttribute("class", "btn btn-sm btn-]]print(off_color) print[[ active");
-    $("#]] print(submit_field) print [[_input").val("]]print(off_value) print[[").trigger('change');]]
+  function ]] print(submit_field) print [[_functionOff(){]]
+
+    print([[$(`#input-]].. submit_field ..[[`).val("]].. off_value ..[["); ]])
+
     if elementToSwitch ~= nil then
       for element = 1, #elementToSwitch do
         if ((hideOn == nil) or (hideOn == false)) then
@@ -527,9 +571,8 @@ function toggleTableButtonPrefs(label, comment, on_label, on_value, on_color , o
       end
     end
 
-    if javascriptAfterSwitch ~= nil then
-      print(javascriptAfterSwitch)
-    end
+    printNestedToSwitchLogic(nested_to_switch, "input-" .. submit_field)
+
     print [[
   }]]
   print('</script>\n')
@@ -542,7 +585,7 @@ local function get_pref_redis_key(options)
 end
 
 function prefsToggleButton(subpage_active, params)
-  defaults = {
+  local defaults = {
     to_switch = {},             -- a list of elements to be switched on or off
     on_text = "On",             -- The text when the button is on
     on_value = "1",             -- The value when the button is on
@@ -551,24 +594,31 @@ function prefsToggleButton(subpage_active, params)
     off_value = "0",            -- The value when the button is off
     off_class = "danger",       -- The css class when the button is off
     reverse_switch = false,     -- If true, elements are hidden when the item is enabled
-    js_after_switch = nil,      -- javascript after switch
+    nested_to_switch = {},      -- Similar to "to_switch" but for nested items
   }
 
   local options = table.merge(defaults, params)
   local redis_key = get_pref_redis_key(options)
 
+  -- used for debugging purpose:
+  -- if (subpage_active.entries[options.field] ~= nil) then
+  --  traceError(TRACE_ERROR, TRACE_CONSOLE, "Missing entry '" .. options.field .. "' inside entries field")
+  -- end
+
   return toggleTableButtonPrefs(params.title or subpage_active.entries[options.field].title,
     (params.description or subpage_active.entries[options.field].description) .. (params.content or subpage_active.entries[options.field].content or ""),
     options.on_text, options.on_value, options.on_class,
     options.off_text, options.off_value, options.off_class,
     options.field, redis_key,
-    options.default, options.disabled, options.to_switch, options.reverse_switch, not options.hidden, options.js_after_switch)
+    options.default, options.disabled, options.to_switch, options.reverse_switch, not options.hidden, options.nested_to_switch)
 end
 
 function multipleTableButtonPrefs(label, comment, array_labels, array_values, default_value, selected_color,
                                   submit_field, redis_key, disabled, elementToSwitch, showElementArray,
-                                  javascriptAfterSwitch, showElement, initialValue, toggleElementArray)
-   local value
+                                  nested_to_switch, showElement, initialValue, toggleElementArray)
+  local value
+  local disabled_attr
+
   if not skip_redis then
    if(_POST[submit_field] ~= nil) then
     local old_v = ntop.getPref(redis_key)
@@ -594,8 +644,10 @@ function multipleTableButtonPrefs(label, comment, array_labels, array_values, de
 
   if (disabled == true) then
     disabled = "disabled"
+    disabled_attr = ' disabled="disabled"'
   else
     disabled = ""
+    disabled_attr = ""
   end
 
   local objRow = ""
@@ -606,10 +658,10 @@ function multipleTableButtonPrefs(label, comment, array_labels, array_values, de
   end
   if(value ~= nil) then
     if(label ~= "") then print('<tr id="row_'..submit_field..'"'..objRow..'><td width=50%><strong>'..label..'</strong><p><small>'..comment..'</small></td><td align=right>\n') end
-    print('<div class="btn-group" data-toggle="buttons-radio" data-toggle-name="'..submit_field..'">')
+    print('<div class="btn-group" data-bs-toggle="buttons-radio" data-bs-toggle-name="'..submit_field..'">')
 
     for nameCount = 1, #array_labels do
-      local type_button = "btn-default"
+      local type_button = "btn-secondary"
       if(value == array_values[nameCount]) then
         local color
         if type(selected_color) == "table" then
@@ -619,11 +671,23 @@ function multipleTableButtonPrefs(label, comment, array_labels, array_values, de
         end
         type_button = "btn-"..color.."  active"
       end
-      print('<button id="id_'..submit_field..'_'..array_values[nameCount]..'" value="'..array_values[nameCount]..'" type="button" class="btn btn-sm '..type_button..' ' .. disabled .. '" data-toggle="button">'..array_labels[nameCount]..'</button>\n')
+      print('<button id="id_'..submit_field..'_'..array_values[nameCount]..'" value="'..array_values[nameCount]..'" type="button" class="btn btn-sm '..type_button..' ' .. disabled .. '"'.. disabled_attr ..' data-bs-toggle="button">'..array_labels[nameCount]..'</button>\n')
     end
     print('</div>\n')
     print('<input type="hidden" id="id-toggle-'..submit_field..'" name="'..submit_field..'" value="'..value..'" />\n')
     print('<script>\n')
+
+    -- showElementArray can be either:
+    --  1. a simple table (e.g. {true, false}): it affects all the elements in elementToSwitch
+    --  2. a nested table (e.g. {{true, false}, {false, false}}): each element in the table
+    --     affects the corresponding element in the elementToSwitch (e.g. {true, false} affects
+    --     elementToSwitch[1], whereas {false, false} affects elementToSwitch[2])
+    if(showElementArray and (type(showElementArray[1]) ~= "table")) then
+      -- This is simple table (case 1.) above, convert it to case 2 to handle
+      -- both cases consinstenly below.
+      showElementArray = {showElementArray, }
+    end
+
     for nameCount = 1, #array_labels do
       print('$("#id_'..submit_field..'_'..array_values[nameCount]..'").click(function() {\n')
       print(' var field = $(\'#id-toggle-'..submit_field..'\');\n')
@@ -643,17 +707,21 @@ function multipleTableButtonPrefs(label, comment, array_labels, array_values, de
         if(array_values[indexLabel] == array_values[nameCount]) then
           print[[class_]] print(array_values[indexLabel]) print[[.setAttribute("class", "btn btn-sm btn-]]print(color) print[[ active");]]
         else
-          print[[class_]] print(array_values[indexLabel]) print[[.setAttribute("class", "btn btn-sm btn-default");]]
+          print[[class_]] print(array_values[indexLabel]) print[[.setAttribute("class", "btn btn-sm btn-secondary");]]
         end
       end
 
       -- Show/Hide all the elementToSwitch items at once
       if (showElementArray ~= nil) then
-        for indexSwitch = 1, #showElementArray do
+        for indexSwitch = 1, #showElementArray[1] do
           if (indexSwitch == nameCount) then
             if elementToSwitch ~= nil then
               for element = 1, #elementToSwitch do
-                if (showElementArray[indexSwitch] == true) then
+                -- Try to get the element-specific configuration if available,
+                -- otherwise fallback to the default configuration (at index 1)
+                local to_apply = showElementArray[element] or showElementArray[1]
+
+                if (to_apply[indexSwitch] == true) then
                   -- NOTE: this is executed into the js change callback
                   print('$("#'..elementToSwitch[element]..'").css("display","table-row");\n')
                 else
@@ -683,9 +751,7 @@ function multipleTableButtonPrefs(label, comment, array_labels, array_values, de
         end
       end
 
-      if javascriptAfterSwitch ~= nil then
-        print(javascriptAfterSwitch)
-      end
+      printNestedToSwitchLogic(nested_to_switch, "id-toggle-" .. submit_field)
 
       print('});\n')
     end
@@ -713,9 +779,9 @@ function loggingSelector(label, comment, submit_field, redis_key)
   end
 
   local logging_values = {"trace", "debug", "info", "normal", "warning", "error"}
-  local color_map = {"default", "success", "info", "primary", "warning", "danger"}
+  local color_map = {"secondary", "success", "info", "primary", "warning", "danger"}
   local logging_keys = {}
-  local color = "default"
+  local color = "secondary"
 
   for i,v in ipairs(logging_values) do logging_keys[i] = firstToUpper(v) end
 
@@ -726,7 +792,7 @@ function loggingSelector(label, comment, submit_field, redis_key)
 end
 
 function printPageSection(section_name)
-   print('<tr><th colspan=2 class="info">'..section_name..'</th></tr>')
+   print('<thead class="table-primary"><tr><th colspan=2 class="info">'..section_name..'</th></tr></thead>')
 end
 
 function printSaveButton(some_content)
