@@ -1,5 +1,5 @@
 --
--- (C) 2013-20 - ntop.org
+-- (C) 2013-21 - ntop.org
 --
 
 dirs = ntop.getDirs()
@@ -13,7 +13,7 @@ sendHTTPContentTypeHeader('text/html')
 
 page_utils.print_header(i18n("about.about_x", { product=info.product }))
 
-if ntop.isEnterprise() and hasNindexSupport() then
+if ntop.isEnterpriseM() and hasNindexSupport() then
   local nindex_utils = require "nindex_utils"
   nindex_utils.deleteOldFLows(true --[[ verbose ]])
 else
