@@ -319,10 +319,6 @@ if (isset($_GET['if'])) {
 
 include("head.inc");
 
-$main_buttons = array(
-    array('label' => gettext('Add'), 'href' => 'firewall_rules_edit.php?if=' . $selected_if),
-);
-
 $a_filter_raw = config_read_array('filter', 'rule');
 legacy_html_escape_form_data($a_filter);
 $all_rule_stats = json_decode(configd_run("filter rule stats"), true);
@@ -437,7 +433,7 @@ $( document ).ready(function() {
   $(".act_toggle").click(function(event){
       event.preventDefault();
       let target = $(this);
-      target.removeClass('fa-play').addClass('fa-spinner fa-pulse');
+      target.addClass('fa-spinner fa-pulse');
       let id = target.attr("id").split('_').pop(-1);
       $.ajax("firewall_rules.php",{
           type: 'post',
@@ -446,18 +442,18 @@ $( document ).ready(function() {
           data: {'act': 'toggle', 'id': id},
           success: function(response) {
               target.prop('title', response['new_label']).tooltip('fixTitle').tooltip('hide');
-              target.removeClass('fa-spinner fa-pulse').addClass('fa-play');
+              target.removeClass('fa-spinner fa-pulse');
               if (response['new_state']) {
-                  target.removeClass('text-muted').addClass('text-success');
+                  target.removeClass('text-muted').addClass(target.hasClass('fa-play') ? 'text-success' : 'text-danger');
               } else {
-                  target.removeClass('text-success').addClass('text-muted');
+                  target.removeClass('text-success text-danger').addClass('text-muted');
               }
               $("#fw-alert-box").removeClass("hidden");
               $(".fw-alert-messages").addClass("hidden");
               $("#fw-alert-changes").removeClass("hidden");
           },
           error: function () {
-              target.removeClass('fa-spinner fa-pulse').addClass('fa-play');
+              target.removeClass('fa-spinner fa-pulse');
           }
       });
   });
@@ -642,7 +638,23 @@ $( document ).ready(function() {
                         <strong><?= gettext('Description') ?></strong>
                         <i class="fa fa-question-circle" data-toggle="collapse" data-target=".rule_md5_hash" ></i>
                       </td>
-                      <td class="button-th"></td>
+                      <td class="text-nowrap button-th">
+                        <a href="<?= url_safe('firewall_rules_edit.php?if=%s', array($selected_if)) ?>" class="btn btn-primary btn-xs" data-toggle="tooltip" title="<?= html_safe(gettext('Add')) ?>">
+                          <i class="fa fa-plus fa-fw"></i>
+                        </a>
+                        <button id="move_<?= count($a_filter) ?>" name="move_<?= count($a_filter) ?>_x" data-toggle="tooltip" title="<?= html_safe(gettext('Move selected rules to end')) ?>" class="act_move btn btn-default btn-xs">
+                          <i class="fa fa-arrow-left fa-fw"></i>
+                        </button>
+                        <button id="del_x" title="<?= html_safe(gettext('Delete selected')) ?>" data-toggle="tooltip" class="act_delete btn btn-default btn-xs">
+                          <i class="fa fa-trash fa-fw"></i>
+                        </button>
+                        <button title="<?= html_safe(gettext('Enable selected')) ?>" data-toggle="tooltip" class="act_toggle_enable btn btn-default btn-xs">
+                          <i class="fa fa-check-square-o fa-fw"></i>
+                        </button>
+                        <button title="<?= html_safe(gettext('Disable selected')) ?>" data-toggle="tooltip" class="act_toggle_disable btn btn-default btn-xs">
+                          <i class="fa fa-square-o fa-fw"></i>
+                        </button>
+                      </td>
                   </tr>
                   <tr id="expand-internal-rules" style="display: none;">
                       <td><i class="fa fa-folder-o text-muted"></i></td>
@@ -701,7 +713,12 @@ $( document ).ready(function() {
                       </td>
                       <td class="view-info hidden-xs hidden-sm">*</td>
                       <td class="view-stats hidden-xs hidden-sm"><?= !empty($rule_stats) ? $rule_stats['evaluations'] : gettext('N/A') ?></td>
-                      <td class="view-stats hidden-xs hidden-sm"><?= !empty($rule_stats) ? $rule_stats['states'] : gettext('N/A') ?></td>
+                      <td class="view-stats hidden-xs hidden-sm">
+<?php if (!empty($rule_stats) && !empty($rule->getRef())):?>
+                          <a href="/ui/diagnostics/firewall/states#<?=html_safe($rule->getLabel());?>" data-toggle="tooltip" title="<?=html_safe("open states view");?>" ><?= $rule_stats['states'];?></a>
+<?php else: ?>
+                          <?= !empty($rule_stats) ? $rule_stats['states'] : gettext('N/A') ?></td>
+<?php endif ?>
                       <td class="view-stats"><?= !empty($rule_stats) ? $rule_stats['packets'] : gettext('N/A') ?></td>
                       <td class="view-stats"><?= !empty($rule_stats) ? format_bytes($rule_stats['bytes']) : gettext('N/A') ?></td>
                       <td><?=$rule->getDescr();?></td>
@@ -842,7 +859,14 @@ $( document ).ready(function() {
                        endif;?>
                     </td>
                     <td class="view-stats hidden-xs hidden-sm"><?= !empty($all_rule_stats[$rule_hash]) ? $all_rule_stats[$rule_hash]['evaluations'] : gettext('N/A') ?></td>
-                    <td class="view-stats hidden-xs hidden-sm"><?= !empty($all_rule_stats[$rule_hash]) ? $all_rule_stats[$rule_hash]['states'] : gettext('N/A') ?></td>
+                    <td class="view-stats hidden-xs hidden-sm">
+<?php if (!empty($all_rule_stats[$rule_hash])):?>
+                      <a href="/ui/diagnostics/firewall/states#<?=html_safe($rule_hash);?>" data-toggle="tooltip" title="<?=html_safe("open states view");?>" ><?= $all_rule_stats[$rule_hash]['states'];?></a>
+<?php else: ?>
+                      <?= gettext('N/A') ?>
+<?php endif ?>
+
+                    </td>
                     <td class="view-stats"><?= !empty($all_rule_stats[$rule_hash]) ? $all_rule_stats[$rule_hash]['packets'] : gettext('N/A') ?></td>
                     <td class="view-stats"><?= !empty($all_rule_stats[$rule_hash]) ? format_bytes($all_rule_stats[$rule_hash]['bytes']) : gettext('N/A') ?></td>
                     <td  class="rule-description">
@@ -878,28 +902,6 @@ $( document ).ready(function() {
                   endforeach;
                   $i++;
 ?>
-                  <tr>
-                    <td colspan="2"></td>
-                    <td colspan="2" class="view-info"></td>
-                    <td colspan="5" class="view-info hidden-xs hidden-sm"></td>
-                    <td colspan="2" class="view-stats hidden-xs hidden-sm"></td>
-                    <td colspan="2" class="view-stats"></td>
-                    <td></td>
-                    <td>
-                      <button id="move_<?=$i;?>" name="move_<?=$i;?>_x" data-toggle="tooltip" title="<?= html_safe(gettext('Move selected rules to end')) ?>" class="act_move btn btn-default btn-xs">
-                        <i class="fa fa-arrow-left fa-fw"></i>
-                      </button>
-                      <button id="del_x" title="<?= html_safe(gettext('Delete selected')) ?>" data-toggle="tooltip" class="act_delete btn btn-default btn-xs">
-                        <i class="fa fa-trash fa-fw"></i>
-                      </button>
-                      <button title="<?= html_safe(gettext('Enable selected')) ?>" data-toggle="tooltip" class="act_toggle_enable btn btn-default btn-xs">
-                          <i class="fa fa-check-square-o fa-fw"></i>
-                      </button>
-                      <button title="<?= html_safe(gettext('Disable selected')) ?>" data-toggle="tooltip" class="act_toggle_disable btn btn-default btn-xs">
-                          <i class="fa fa-square-o fa-fw"></i>
-                      </button>
-                    </td>
-                  </tr>
                 </tbody>
               </table>
               <table class="table table-condensed table-striped opnsense-rules">
