@@ -164,7 +164,7 @@ if ($_SERVER['REQUEST_METHOD'] === 'GET') {
       }
     }
 
-    if (!empty($pconfig['gateway']) && !is_ipaddrv4($pconfig['gateway'])) {
+    if (!empty($pconfig['gateway']) && $pconfig['gateway'] != "none" && !is_ipaddrv4($pconfig['gateway'])) {
         $input_errors[] = gettext("A valid IP address must be specified for the gateway.");
     }
 
@@ -173,7 +173,7 @@ if ($_SERVER['REQUEST_METHOD'] === 'GET') {
         $input_errors[] = gettext("A valid IP address must be specified for the primary/secondary WINS servers.");
     }
 
-    if (is_subnetv4($parent_net) && !empty($pconfig['gateway'])) {
+    if (is_subnetv4($parent_net) && $pconfig['gateway'] != "none" &&  !empty($pconfig['gateway'])) {
         if (!ip_in_subnet($pconfig['gateway'], $parent_net) && !ip_in_interface_alias_subnet($if, $pconfig['gateway'])) {
             $input_errors[] = sprintf(gettext("The gateway address %s does not lie within the chosen interface's subnet."), $_POST['gateway']);
         }
@@ -354,7 +354,6 @@ include("head.inc");
                     <input name="hostname" type="text" value="<?=$pconfig['hostname'];?>" />
                     <div class="hidden" data-for="help_for_hostname">
                       <?=gettext("Name of the host, without domain part.");?>
-                      <?=gettext("If no IP address is given above, hostname will not be visible to DNS services with lease registration enabled.");?>
                     </div>
                   </td>
                 </tr>
@@ -385,7 +384,7 @@ include("head.inc");
                   <td>
                     <input name="descr" type="text" value="<?=$pconfig['descr'];?>" />
                     <div class="hidden" data-for="help_for_descr">
-                      <?=gettext("You may enter a description here ". "for your reference (not parsed).");?>
+                      <?=gettext("You may enter a description here for your reference (not parsed).");?>
                     </div>
                   </td>
                 </tr>
@@ -420,7 +419,9 @@ include("head.inc");
                   <td>
                     <input name="gateway" type="text" value="<?=$pconfig['gateway'];?>" />
                     <div class="hidden" data-for="help_for_gateway">
-                      <?=gettext("The default is to use the IP on this interface of the firewall as the gateway. Specify an alternate gateway here if this is not the correct gateway for your network.");?>
+                      <?=gettext('The default is to use the IP on this interface of the firewall as the gateway. '.
+                                 'Specify an alternate gateway here if this is not the correct gateway for your network. ' .
+                                 'Type "none" for no gateway assignment.');?>
                     </div>
                   </td>
                 </tr>
