@@ -65,27 +65,31 @@ if ($_REQUEST['updateme']) {
             if (substr($tmp, 0, 6) == '$GPRMC') {
                 $gps_vars = explode(",", $tmp);
                 $gps_ok  = ($gps_vars[2] == "A");
-                $gps_lat_deg = substr($gps_vars[3], 0, 2);
-                $gps_lat_min = substr($gps_vars[3], 2) / 60.0;
-                $gps_lon_deg = substr($gps_vars[5], 0, 3);
-                $gps_lon_min = substr($gps_vars[5], 3) / 60.0;
-                $gps_lat = $gps_lat_deg + $gps_lat_min;
-                $gps_lat = $gps_lat * (($gps_vars[4] == "N") ? 1 : -1);
-                $gps_lon = $gps_lon_deg + $gps_lon_min;
-                $gps_lon = $gps_lon * (($gps_vars[6] == "E") ? 1 : -1);
+                if ($gps_ok) {
+                    $gps_lat_deg = substr($gps_vars[3], 0, 2);
+                    $gps_lat_min = substr($gps_vars[3], 2) / 60.0;
+                    $gps_lon_deg = substr($gps_vars[5], 0, 3);
+                    $gps_lon_min = substr($gps_vars[5], 3) / 60.0;
+                    $gps_lat = $gps_lat_deg + $gps_lat_min;
+                    $gps_lat = $gps_lat * (($gps_vars[4] == "N") ? 1 : -1);
+                    $gps_lon = $gps_lon_deg + $gps_lon_min;
+                    $gps_lon = $gps_lon * (($gps_vars[6] == "E") ? 1 : -1);
+                }
                 $gps_la = $gps_vars[4];
                 $gps_lo = $gps_vars[6];
             } elseif (substr($tmp, 0, 6) == '$GPGGA') {
                 $gps_vars = explode(",", $tmp);
                 $gps_ok  = $gps_vars[6];
-                $gps_lat_deg = substr($gps_vars[2], 0, 2);
-                $gps_lat_min = substr($gps_vars[2], 2) / 60.0;
-                $gps_lon_deg = substr($gps_vars[4], 0, 3);
-                $gps_lon_min = substr($gps_vars[4], 3) / 60.0;
-                $gps_lat = $gps_lat_deg + $gps_lat_min;
-                $gps_lat = $gps_lat * (($gps_vars[3] == "N") ? 1 : -1);
-                $gps_lon = $gps_lon_deg + $gps_lon_min;
-                $gps_lon = $gps_lon * (($gps_vars[5] == "E") ? 1 : -1);
+                if ($gps_ok) {
+                    $gps_lat_deg = substr($gps_vars[2], 0, 2);
+                    $gps_lat_min = substr($gps_vars[2], 2) / 60.0;
+                    $gps_lon_deg = substr($gps_vars[4], 0, 3);
+                    $gps_lon_min = substr($gps_vars[4], 3) / 60.0;
+                    $gps_lat = $gps_lat_deg + $gps_lat_min;
+                    $gps_lat = $gps_lat * (($gps_vars[3] == "N") ? 1 : -1);
+                    $gps_lon = $gps_lon_deg + $gps_lon_min;
+                    $gps_lon = $gps_lon * (($gps_vars[5] == "E") ? 1 : -1);
+                }
                 $gps_alt = $gps_vars[9];
                 $gps_alt_unit = $gps_vars[10];
                 $gps_sat = $gps_vars[7];
@@ -94,14 +98,16 @@ if ($_REQUEST['updateme']) {
             } elseif (substr($tmp, 0, 6) == '$GPGLL') {
                 $gps_vars = explode(",", $tmp);
                 $gps_ok  = ($gps_vars[6] == "A");
-                $gps_lat_deg = substr($gps_vars[1], 0, 2);
-                $gps_lat_min = substr($gps_vars[1], 2) / 60.0;
-                $gps_lon_deg = substr($gps_vars[3], 0, 3);
-                $gps_lon_min = substr($gps_vars[3], 3) / 60.0;
-                $gps_lat = $gps_lat_deg + $gps_lat_min;
-                $gps_lat = $gps_lat * (($gps_vars[2] == "N") ? 1 : -1);
-                $gps_lon = $gps_lon_deg + $gps_lon_min;
-                $gps_lon = $gps_lon * (($gps_vars[4] == "E") ? 1 : -1);
+                if ($gps_ok) {
+                    $gps_lat_deg = substr($gps_vars[1], 0, 2);
+                    $gps_lat_min = substr($gps_vars[1], 2) / 60.0;
+                    $gps_lon_deg = substr($gps_vars[3], 0, 3);
+                    $gps_lon_min = substr($gps_vars[3], 3) / 60.0;
+                    $gps_lat = $gps_lat_deg + $gps_lat_min;
+                    $gps_lat = $gps_lat * (($gps_vars[2] == "N") ? 1 : -1);
+                    $gps_lon = $gps_lon_deg + $gps_lon_min;
+                    $gps_lon = $gps_lon * (($gps_vars[4] == "E") ? 1 : -1);
+                }
                 $gps_la = $gps_vars[2];
                 $gps_lo = $gps_vars[4];
             }
@@ -144,7 +150,7 @@ endif; ?>
       <tr>
         <td style="width:40%"><?= gettext('Clock location') ?></td>
         <td style="width:60%">
-          <a target="_gmaps" href="http://maps.google.com/?q=<?= html_safe($gps_lat) ?>,<?= html_safe($gps_lon) ?>">
+          <a target="_gmaps" href="https://maps.google.com/?q=<?= html_safe($gps_lat) ?>,<?= html_safe($gps_lon) ?>">
           <?php
                     echo sprintf("%.5f", $gps_lat) . " " . $gps_la . ", " . sprintf("%.5f", $gps_lon) . " " . $gps_lo; ?>
           </a>
